clear
set more off
capture log close
log using OSS.log, replace

foreach y of global YEAR {

use AGGmaster`y', clear

************************************************
** Feenstra and Hanson (1999) measures of OSS **
**********************************************************************
** Remember that FH_IMPINT is a N x N matrix of import intensity    **
** by industry.  Each observation matches up with the corresponding **
** industry weight.                                                 **
**********************************************************************

matrix OSS = J(34,34,0)

forvalues i = 1(1)34 {
  forvalues j = 1(1)34 {
    matrix OSS[`i',`j'] = w[`i',`j'] * FH[`i',`j']
   }
  }

**********************************************************************
** The wide measure of outsourcing looks at all inputs into a given **
** industry.  This is the column sum.                               **
** We follow the same idea as in 'Total_Purchase.Do'                **
** Transpose the matrix OSS, sum across rows                        **
**********************************************************************

matrix OSST = OSS'
svmat OSST, names(col)

egen FH_OSS_WIDE = rowtotal(r1-r34)
drop r1-r34

**********************************************************************
** OSS is still a 34 X 34 square matrix                             **
** I use the vecdiag() function, which takes the diagonal           **  
** and makes a column vector.                                       **
** The column vectors can be more easily worked with in excel or in **
** regressions in Stata.                                            **
**********************************************************************

matrix FH_OSS_narrow = vecdiag(OSS)
matrix FH_OSS_Narrow = FH_OSS_narrow'
svmat FH_OSS_Narrow, name(FH_OSS_Narrow)

******************************************
** Amiti and Wei (2004) measures of OSS **
******************************************
** Note this notation might seem slightly confusing
** AW_IMPINT is a 34 X 1 matrix, where cell(1,1) is industry 1, cell(2,1) is industry 2, etc.
** We want to multiply all of the weights for industry i (the column) by the corresponding AW_IMPINT cell
** The use of `i'  fixes the column headings to accomplish this goal

mkmat AW_IMPINT, matrix(AW_IMPINT)
 
matrix AW_OSS = J(34,34,0)

forvalues i = 1(1)34 {
  forvalues k = 1(1)34 {
    matrix AW_OSS[`k',`i'] = w[`k',`i'] * AW_IMPINT[`i',1]
   }
  }

matrix AW_OSST = AW_OSS'
svmat AW_OSST, names(col)

egen AW_OSS_WIDE = rowtotal(r1-r34)
drop r1-r34

matrix AW_OSS_narrow = vecdiag(AW_OSS)
matrix AW_OSS_Narrow = AW_OSS_narrow'
svmat AW_OSS_Narrow, name(AW_OSS_Narrow)

********************************
** Save and Output the Data   **
********************************

save AGGmaster`y', replace

keep class FH_OSS_WIDE FH_OSS_Narrow AW_OSS_WIDE AW_OSS_Narrow

rename FH_OSS_WIDE FH_OSS_WIDE_`y'
rename FH_OSS_Narrow FH_OSS_Narrow_`y'
rename AW_OSS_WIDE AW_OSS_WIDE_`y'
rename AW_OSS_Narrow AW_OSS_Narrow_`y'

save results/OSS_results_`y', replace
save OSS_results_`y', replace

outsheet using results/OSS_results_`y', replace


}

log close
exit

