clear
capture log close
log using AGGimpint.log, replace

set more off

foreach y of global YEAR {

use AGGmaster`y', clear

***************************************************************
** Generate two measures of impint
** AW_impint uses the simplifying assumption and reports a single measure
** by industry.
**
** FH_impint uses the I-O table to generate a full matrix of impint by 
** inputs of each industry (j) to an industry (i)
***************************************************************

***************
** AW_IMPINT **
***************************************************************
** Domestic production is defined in the 'GetData.do' file   **
***************************************************************

generate AW_IMPINT = total_intermediate_import / domesticproduction

****************
** FH_IMPINT  **
****************
**  This loop creates two matrices from the Import I-O and Domestic I-O table
**  It then performs elementwise division of import of input / domestic production of input
**  for each industry i and input j

** Note that we make the matrix with the variables i1 through i36, but that the size of the matrix is really
** a 34x34 matrix, because we exclude i2 and i3 (energy and coal/nuclear fuel)

mkmat i1-i48, matrix(I)

mkmat d1-d48, matrix(D)

matrix FH = J(34,34,0)

forvalues i = 1(1)34 {
  forvalues j = 1(1)34 {
    matrix FH[`i',`j'] = I[`i',`j'] / D[`i',`j']
   }
  }


save AGGmaster`y', replace
}

log close
exit
