clear
capture log close
log using AGGtotal_purchase.log, replace

set more off

foreach y of global YEAR {

use AGGmaster`y', clear

***************************************************************
** This generates the total non energy inputs by industry i  **
** By creating a matrix, transposing the data and creating   **
** new variables r1 - r48.  Stata operates by rows.  Thus,   **
** Summing up variables r1 thru 48 is now the same operation **
** as summing up the variable t1 (the column of total inputs **
** for ISICN industry 1                                      **
***************************************************************

mkmat t1-t48, matrix(T)

*** Transpose the data

matrix t = T'

*** The command svmatt turns the matrix T into a series of variables, with the columns named r1 thru r48.  
***  Each number corresponds to the industry.  That is, r1 entry 2 is input into industry two. 

svmat t, names(col)


*** Total purchases exclude the industries with 'class' = 2 or 3
*** This drops the following industries involved in energy production:
*** Mining/Quaryying (energy), Coke/Refined Petroleum, Electricity, Gas, Steam
** NOTE: the command 'svmat' creates the variables r1 thru r36 -- these correspond to the variables t1-t48 
** except that the 't' variables skip, ie no 't21' 't22' etc. 'r' variables created in sequential order, so
** it is safe to drop r2 and r3 (which correspond to t2 and t3) 

egen total_purchase =  rowtotal(r1-r34)
drop r1-r34 _merge1 _merge2 

save AGGmaster`y', replace
}

log close
exit


