clear
set more off
capture log close
log using weight.log, replace

foreach y of global YEAR {

use AGGmaster`y', clear

*******************************************************************
** This loop calculates the weight of each input into the total  
** purchase by the industry.                                     
** w(i,j) = purchase of input j by industry i divided by total     
**   purchase of all non energy inputs by industry i.            
**  
** Total Purchase of all non energy inputs is created using 'total_purchase.do' 
**  and is the column sum of the I-O table.  
**  
** Total Purchase is a 36 x 1 column vector, where cell(1,1) is total purchase of industry 1,
**  cell(2,1) is total purchase of industry 2, etc.  Note, that the 36 rows map sequentially
** to the variable class.  So for class 6 and class 8 we have row 6 and 7 respectively, since class 7 
** does not exist due to aggregation.
** 
** The notation on the two for loops seems slightly counter intuitive since total_purchase is a column vector.
** I use the indice `k' so as not to confuse with the I-O table i,j
** 
** The first loop `i' fixes the row of the total purchase vector and the column vector of both the weight and I-O table.
** The second loop `k' fixes the row of the weight and I-O table.
** This divides each row of column 1 by the corresponding total purchase in cell(1,1) 
*******************************************************************

 
************************************************************************
** This is a square matrix without any energy inputs.                  *
************************************************************************

mkmat t1-t48, matrix(T)

mkmat total_purchase, matrix(TT)

matrix w = J(34,34,0)

forvalues i = 1(1)34 {
  forvalues k = 1(1)34 {
    matrix w[`k',`i'] = T[`k',`i'] / TT[`i',1]
   }
  }


save AGGmaster`y', replace
}

log close
exit