* This program uses the STATA command 'COLLAPSE' to generate new row totals
*  The goal is to aggregate the OECD I-O table to the same industry concordance povided
*  byt the 1995 IAB Establishment Panel Survey. 

clear
set mem 600m
capture log close
log using aggregation.log, replace
set more off


** ADD YEAR macro later **

use total1995, clear

** First step is to generate the variable 'class' created based on the IAB establishment data
** Note: Same program used for the KLEMS data

generate class = isicn
label var class "classification of industries"
label values class clabel


***********************************************
**             CONCORDANCE                   **
***********************************************

replace class = 1 if isicn == 1
label define clabel 1 "agriculture, hunting, forestry and fishing", modify

replace class = 2 if isicn == 2 | isicn == 3 | isicn == 26 | isicn == 27 | isicn == 28 | isicn == 29
label define clabel 2 "mining and quarrying plus electricity gas water", modify

replace class = 3 if isicn == 8 | isicn == 9
label define clabel 3 "Chemicals, coke, refined petroleum, nuclear fuel", modify

replace class = 4 if isicn == 11 
label define clabel 4 "Rubber and Plastic Products", modify

replace class = 5 if isicn == 12
label define clabel 5 "Other non-metallic products", modify

replace class = 6 if isicn == 13 | isicn == 14 | isicn == 15
label define clabel 6 "Fabricated Metal products, ex machinery", modify

replace class = 8 if isicn == 16
label define clabel 8 "Machinery", modify
 
replace class = 9 if isicn == 21 | isicn == 22 | isicn == 23 | isicn == 24
label define clabel 9 "Transport Equipment", modify

replace class = 11 if isicn == 18 | isicn == 20
label define clabel 11 "Electrical and Optical Equipment", modify

replace class = 13 if isicn == 6
label define clabel 13 "Wood products", modify

replace class = 14 if isicn == 7
label define clabel 14 "Pulp, Paper, PrintPub", modify

replace class = 15 if isicn == 5
label define clabel 15 "Textiles, Leather, Footwear", modify

replace class = 16 if isicn == 4
label define clabel 16 "Food Beverage", modify

*******************************************************
*                 ROW AGGREGATION
* Use the collapse statement to create a new row that 
* is the sum of all categories with like tag values
*******************************************************

collapse(sum) t1-t48, by(class)

** Label remaining classification codes, for consistency
label define clabel 10 "pharmaceuticals", modify
label define clabel 17 "office, accounting and computing machinery", modify
label define clabel 19 "radio, tv, communication equipment", modify
label define clabel 25 "manufacturing nec; recycling", modify
label define clabel 30 "construction", modify
label define clabel 31 "wholesale, retail trade", modify
label define clabel 32 "hotels and restaurants", modify
label define clabel 33 "land transport via pipelines", modify
label define clabel 34 "water transport", modify
label define clabel 35 "air transport", modify
label define clabel 36 "activities of travel", modify
label define clabel 37 "post and telecomm", modify
label define clabel 38 "finance and insurance", modify
label define clabel 39 "real estate", modify
label define clabel 40 "renting of machinery", modify
label define clabel 41 "computer and related", modify
label define clabel 42 "research and develop", modify
label define clabel 43 "other business act.", modify
label define clabel 44 "public admin", modify
label define clabel 45 "education", modify
label define clabel 46 "health and social work", modify
label define clabel 47 "other community", modify
label define clabel 48 "private households", modify

**********************************************************
*           COLUMN AGGREGATION    
*  rename variables to have same class number 
*  Need square matrix for outsourcing calculation
*  Note: I use 'aggt##' as a placeholder - in some instances
*  I switcha  isicn to a class #, but need to switch a different isicn to 
*  the previous class #.  See industry 4 (Food products --> class 16) and industry 16 (class -> 8)
*  I can't replace isicn 4 to class 16 without overwriting the existing industry 16,
*  Hence the need for a placeholder
**********************************************************

generate aggt2 = t2 + t3 + t26 + t27 + t28 + t29
drop t2 t3 t26 t27 t28 t29
rename aggt2 t2

generate aggt3 = t8 + t9
drop t8 t9
rename aggt3 t3

generate aggt6 = t13 + t14 + t15
drop t13 t14 t15

rename t6 t13
rename aggt6 t6

generate aggt9 = t21 + t22 + t23 + t24
drop t21 t22 t23 t24
rename aggt9 t9

generate aggt11 = t18 + t20
drop t18 t20

rename t4 aggt16
rename t16 aggt8

rename aggt16 t16
rename aggt8 t8

rename t5 t15
rename t7 t14

rename t11 t4
rename aggt11 t11

rename t12 t5

*************************************
** Place variables in numerical order
**  MAKE SQUARE MATRIX               
*************************************

sort class      /* puts rows in numeric order 
aorder          /* puts columns in alphabetical (this case, numeric) order */
compress

save AGGtotal1995, replace