** Master file of the project "Outsourcing and Firm Productivity"
* Sumon Bhaumik (Brunel University, United Kingdom), Craig Aubuchon (Federal Reserve Bank St. Louis), Subhayu Bandyopadhyay (FRB STL)
* Project fdz223 nGA

clear 
set more off
set linesize 255

*Note: Before sending to IAB, switch to the cd.. extension 

*cd "C:\h1cpa01\work\Subhayu\Outsourcing and Firm Productivity\IAB fdz223 nGA"
cd ..
adopath + prog

* Gather Data
*do prog/1_IABdata00.do
*do prog/1A_IABdata99.do
*do prog/1B_IABdata95.do
*do prog/1C_IABdata96.do
*do prog/2_IABdata01.do

*do prog/3_IABdata05.do
*do prog/3A_IABdata04.do
*do prog/3B_IABdata03.do
*do prog/4_IABdata06.do

* Create Class variable for necessary data sets
*do prog/5_concordance2001.do
*do prog/6_concordance2006.do
*do prog/7_HHIconcordance.do


* Merge IAB data with outsourcing and HHI measures
*do prog/8_IAB_merge00.do
*do prog/9_IAB_merge05.do

* Generate measures of capital stock using KLEMS capital/output ratio and PIM method 
do prog/10_CapitalStock.do 

* Create dependent variables, independent variables, including IV variables for both 2000 and 2005
do prog/11_FrontierPrep.do
do prog/12_Summarize.do

* Perform Frontier Analysis
*capture noisily do "prog/13_Frontier00 w Klems.do"
*capture noisily do "prog/14_Frontier05 w Klems.do"

*capture noisily do "prog/15_Frontier00 w K_PIMEST.do"
*capture noisily do "prog/16_Frontier05 w K_PIMEST.do"

* Perform Regression Analysis on labor productivity (output per emp), profit per emp, profit per sales, and log labor productivity
*  Note that cap1 is for KLEMS measure of capital stock, cap2 is for PIM estimate of capital stock

*capture noisily do prog/20AT_lprod00.do
*capture noisily do prog/21AT_lprod05.do

*capture noisily do prog/22AT_ppe00.do
*capture noisily do prog/23AT_ppe05.do

*capture noisily do prog/24A_pps00.do
*capture noisily do prog/25A_pps05.do

*capture noisily do prog/26AT_qreg_00.do
*capture noisily do prog/27AT_qreg_05.do

*capture noisily do prog/28_lnlprod00_cap1.do
*capture noisily do prog/29_lnlprod00_cap2.do
*capture noisily do prog/30_lnlprod05_cap1.do
*capture noisily do prog/31_lnlprod05_cap2.do

*capture noisily do prog/32_IVregressions00.do
*capture noisily do prog/33_IVregressions05.do

*capture noisily do prog/34_IVreg00_onelag.do
*capture noisily do prog/35_IVreg05_onelag.do

* Perform final regression specifications for nonIV models, FH, HHI_minor specifications

*capture noisily do prog/36_estout_reg00.do
*capture noisily do prog/37_estout_reg05.do

* More detailed IV regressions for the favored FH, HHI_minor specifications
* May 19 update includes the endogtest() option, which runs the Hausman test for OLS vs IV
*  Also includes test of KLEMS IV with using capemp as endogenous

*capture noisily do prog/38_FH_IVreg00_onelag.do
*capture noisily do prog/39_FHnarrow_IVreg00_onelag.do
*capture noisily do prog/40_FH_IVreg05_onelag.do
*capture noisily do prog/41_FHnarrow_IVreg05_onelag.do

* Check for robustness - use the OSS measure;

*capture noisily do prog/42_estout_OSS_reg00.do
*capture noisily do prog/43_estout_OSS_reg05.do
*capture noisily do prog/44_OSS_IVreg00_onelag.do
*capture noisily do prog/45_OSSnarrow_IVreg00_onelag.do
*capture noisily do prog/46_OSS_IVreg05_onelag.do
*capture noisily do prog/47_OSSnarrow_IVreg05_onelag.do

* Try to find appropriate combinations of instruments for the Sargan test - FH Broad, Klems;
capture noisily do prog/48_FH_IVreg_lntlprod00_instruments.do
capture noisily do prog/49_FH_IVreg_lntlprod05_instruments.do


capture log close
log using log/datalist.log, replace
dir prog
dir log
dir data
dir doc
log close

