* Program file of the project "Outsourcing and Firm Productivity" - 10_CapitalStock.do
* Contents: Merge 2000 and 2005 data to create a full panel
*           Create two measures of Capital Stock from the capital/output ratio from KLEMS database (industry level)
*           and the perpetual inventory method with the average growth rate and a predetermined depreciation rate (0.06).
*            
*
* Level of Aggregation:  Klems capital/output ratio and average growth rate are both industry level data.  Note that the data 
*                         file 'agg_output_growth' uses external data from OECD and does not violate user agreement with IAB.

clear 
clear matrix
set mem 600m

capture log close
log using log/10_CapitalStock.log, replace

# delimit ;

*-------------------------------------------------------;
use data/8_IAB_merge00, clear ;

merge idnum using data/9_IAB_merge05, sort nolabel  ;

tabulate _merge;
drop _merge ;

/* Note that we want to keep all values here - observations from either 2000 or 2005 */;

* Change all values to missing, if coded with an -8 or -9 (data transformations for output, int_investment;
mvdecode _all, mv(-9 -8 -.009 -.008) ;

*-------------------------------------------------------;
sort class ;
save data/10_CapitalStock.dta, replace ;

*-------------------------------------------------------;
* Merge data with the Grossed Fixed Capital dataset (GFCdata.dta) ;
* GFC.dta contains the capital to output ratios from the KLEMS data file;
* Express Capital Stock measure in thousands of Euros - convert output to euros in 2000, scale in both years ;

merge class using orig/GFCdata.dta ;
drop ratio_1992-ratio_1994 ratio_1996-ratio_1998 ratio_2001-ratio_2003 desc code;

keep if _merge == 3 ;
drop _merge ;

generate Klems95 = ratio_1995 *  output95  ;
generate Klems99 = ratio_1999 *  output99  ;
generate Klems00 = ratio_2000 *  output00  ;
generate Klems04 = ratio_2004 *  output04  ; 
generate Klems05 = ratio_2005 *  output05  ;

*-------------------------------------------------------;
* Merge data with estimates of output growth from OECD I-O tables;
* Calculate measure of Capital Stock based on equations 11 and 12;
* http://www.treasury.govt.nz/publications/research-policy/wp/2006/06-01/07.htm;
* Express Capital Stock measure in thousands of Euros - scale in both years ;

sort class;
merge class using orig/agg_output_growth.dta ;

keep if _merge == 3 ;
drop _merge ;

generate dep_rate = 0.06 ;

generate K_PIMEST_00 =  tot_invest00  / (output_growth00_05 + dep_rate );
generate K_PIMEST_05 =  tot_invest05  / (output_growth00_05 + dep_rate ); 


** Pairwise correlation between measures of Capital Stock ;
** PWCORR gives the correlation, number of observations and signficance level ;

pwcorr Klems00 K_PIMEST_00 Klems05 K_PIMEST_05, obs sig ;


sort idnum ;
save data/10_CapitalStock.dta, replace ;
log close ;
 
 
 
 

 
 


 








