* Program file of the project "Outsourcing and Firm Productivity" - 1_IABdata00.do
* Contents: Keep necessary variables from the 2000 year 

* Level of Aggregation:  Firm level IAB data
* Need to deflate Deutsche Mark to Euros.  See http://www.ecb.int/press/pr/date/1998/html/pr981231_2.en.html for conversion rate

clear 
set mem 600m

capture log close
log using log/1_IABdata00.log, replace


# delimit ;

use orig/test2000.dta, clear;

** Collect relevant variables from the 2001 IAB panel ;
** Rename variables ;

keep idnum h79 h81b h80 h73 h74 h47fach h47unge h42 h44 h45 h09 h12 h01ges99 ;

* Change all values to missing, if coded with an -8 or -9 (before data transformations for output, int_investment;
mvdecode _all, mv(-9 -8) ;

* h81b is current industry classification ;

* presence of a works council ;
rename h79 workcounc00 ;
label var workcounc00 "Works Council 2000" ;

* ownership type ;
rename h80 owner00 ;
label var owner00 "ownership type 2000" ; 

* Company founded before/after 1990 ;
label var h73 "Formation before/after 1990 ?" ;

* Year founded ;
generate age00 = h74 + 1900;
label var age00 "Year Company founded if before 1990" ;
drop h74;
** NOTE: if _merge on idnum == 3 then age and age00 variables should be equal ;

* Total Skilled Employees ;
rename h47fach skill_emp00 ;
label var skill_emp00 "Total Skilled Employees 2000" ; 

* Total Non Skilled Employees ;
rename h47unge nonskill_emp00 ;
label var nonskill_emp00 "Total Non Skilled Employees 2000" ; 

* Importance of collective agreement ;
rename h42 stdpay00 ;
label var stdpay00 "Pay according to collective agreement?" ;

* Wages paid above standard rate ; 
rename h44 hghpay00 ;
label var hghpay00 "Wages paid above stnd rate" ;

* Gross Salaries in June - no contributions to social security ;
generate pay00 = h45 / 1955.83 ;
label var pay00 "Gross Pay in June 00, expressed in thousands of euros" ;
drop h45;

* Quality of capital ;
rename h09 qualcap00 ;
label var qualcap00 "Quality of Capital 2000" ;


* 1999 output in DM, used as lag for IV ;
* Convert DM to Euros using fixed exchange rate;

generate output99 = h12 / 1955.83 ;
label var output99 "Sales in 1999, thousands of euros" ; 
drop h12 ;

* Total Employees in 1999, used as lag for IV ;
rename h01ges99 emp99 ;
label var emp99 "Total Employees 1999" ;

* Change all values to missing, if coded with an -8 or -9 ;
mvdecode _all, mv(-9 -8) ;

save data/1_IABdata00.dta, replace ;

sort idnum;  
log close ;


