* Program file of the project "Outsourcing and Firm Productivity" - 2_IABdata01.do
* Contents: Keep necessary variables from the 2001 data set, for analysis on the 2000 year 
*           Merge yr2000 data from 1_IABdata00 to create a panel

* Level of Aggregation:  Firm level IAB data
* NOTE: Need to deflate Deutsche Mark to Euros.  See http://www.ecb.int/press/pr/date/1998/html/pr981231_2.en.html for conversion rate

clear 
set mem 600m

capture log close
log using log/2_IABdata01.log, replace


# delimit ;

use orig/test2001.dta, clear;

** Collect relevant variables from the 2001 IAB panel ;
** Rename variables ;

keep idnum i92b i07  i10 i09 i25 i01ges00 i12 ;

* Change all values to missing, if coded with an -8 or -9 (before data transformations for output, int_investment;
mvdecode _all, mv(-9 -8) ;

* i92b is current industry classification ;

* 2000 output in DM ;
generate output00 = i07 / 1955.83 ;
label var output00 "Sales in 2000, thousands of euros" ; 
drop i07 ;

* 2000 type of volume ;
rename i10 voltype00 ;
label var voltype00 "Type volume in 2000" ;
label values voltype00 type ;

* Profit in 2000 (DM) ; 
rename i09 profitability00 ;
label var profitability00 "Profitability in 2000" ;

* Total business investment in 2000 ;
generate tot_invest00 = i25 / 1955.83 ;
label var tot_invest00 "total investment 2000, thousands of euros" ;
drop i25;

* Total Employees ;
rename i01ges00 emp00 ;
label var emp00 "Total Employees 2000" ;

* Intermediate input share of turnover ;
generate intinput00 = i12 / 100 ;
label var intinput00 "Intermediate Inputs Share of Turnover 2000, as percent" ;
drop i12;


* Change all values to missing, if coded with an -8 or -9 ;
mvdecode _all, mv(-9 -8) ;

sort idnum;

merge idnum using data/1_IABdata00.dta;
tab _merge;
keep if _merge == 3;
drop _merge;
sort idnum;
* There are some records with all missing values - these are firms that are in both panels but don't have the variables we are interested in;
drop if h81b == .;

* Now, merge in the lag variables;
merge idnum using data/1A_IABdata99 data/1B_IABdata95 data/1C_IABdata96 ; 
* And drop all observations that don't have data in the year 2000 - we'll use h81b for this ;
drop if h81b == . ;
drop g87b _merge1 cz07b _merge2 d81b _merge3 _merge;

save data/2_IABdata01.dta, replace ; 
log close ;


