* Program file of the project "Outsourcing and Firm Productivity" - 3_IABdata05.do
* Contents: Keep necessary variables from the 2005 data set, for analysis on the 2005 year 

* Level of Aggregation:  Firm level IAB data

clear 
set mem 600m

capture log close
log using log/3_IABdata05.log, replace


# delimit ;

use orig/test2005.dta, clear;

** Collect relevant variables from the 2005 IAB panel ;
** Rename variables ;

keep idnum m95b m85a m91 m92 m93 m08 m27fach m27unge m52 m54 m59 m26 m08 m01ges04;

* Change all values to missing, if coded with an -8 or -9 (before data transformations for output, int_investment;
mvdecode _all, mv(-9 -8) ;

* m95b is current industry classification ;

* presence of a works council ;
rename m85a workcounc05 ;
label var workcounc05 "Works Council 2005" ;

* ownership type ;
rename m91 owner05 ;
label var owner05 "ownership type 2005" ; 

* Company founded before/after 1990 ;
label var m92 "Formation before/after 1990 ?" ;

* Year founded ;
rename m93 age05 ;
label var age05 "Year Company founded if before 1990" ;
** NOTE: if _merge on idnum == 3 then age and age05 variables should be equal ;

* Total Skilled Employees ;
rename m27fach skill_emp05 ;
label var skill_emp05 "Total Skilled Employees 2005" ; 

* Total Non Skilled Employees ;
rename m27unge nonskill_emp05 ;
label var nonskill_emp05 "Total Non Skilled Employees 2005" ; 

* Importance of collective agreement ;
rename m52 stdpay05 ;
label var stdpay05 "Pay according to collective agreement?" ;

* Wages paid above standard rate ; 
rename m54 hghpay05 ;
label var hghpay05 "Wages paid above stnd rate" ;

* Gross Salaries in June - no contributions to social security ;
generate pay05 = m59 / 1000 ;
label var pay05 "Gross Pay in June 05, in thousands of euros " ;
drop m59;

* Quality of capital ;
rename m26 qualcap05 ;
label var qualcap05 "Quality of Capital 2005" ;

* 2004 output (in Euros), used as lag for IV ;
* Convert DM to Euros using fixed exchange rate;

generate output04 = m08 / 1000;
label var output04 "Sales in 2004, thousands of euros" ; 
drop m08 ;

* Total Employees in 2004, used as lag for IV ;
rename m01ges04 emp04 ;
label var emp04 "Total Employees 2004" ;


* Change all values to missing, if coded with an -8 or -9 ;
mvdecode _all, mv(-9 -8) ;

sort idnum;
save data/3_IABdata05.dta, replace ; 
log close ;


