* Program file of the project "Outsourcing and Firm Productivity" - 48_FH_IVreg_lntlprod00_instruments.do
* Contents: Perform IV regression analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure
*           We use one and five year lag of endogenous variables, and age dummy as instruments

*           
*             I include both combinations of capital stock for the labor productivity measure, since we can use a one year lag of KLEMS
*             as an instrument.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

*           We include IV regressions for (ii - vi) above, controlling for capqual, skill_labour and lnoutput

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear
clear matrix
set mem 600m
set more off

capture log close



use data/11_FrontierPrep.dta

log using log/48_FH_IVreg_lntlprod00_instruments.log, replace

******************************************************
*Generate dummy variables for light and heavy industry per correspondence with Sumon on 6/27/2010

*Light Industry is: Food and Beverage, Textiles, Leather, Footwear, Wood Products, and Pulp, Paper and Printing Publishing
*Heavy Industry is: Rubber and Plastic Products, Other Non-Metallic Products Manufacture of Basic Metals, fabricated metal products, except machinery
*Machinery, Transport Equipment, and Electrical and Optical Equipment

*Switched out class as an instrument and put in the light dummy variable 6/29/2010
*Removed "light" as an instrument and incorporated it into the regression specification 6/30/2010
******************************************************

gen heavy=.
gen light=.


capture program drop dummymaker
program define dummymaker


foreach x of local 0 {
replace $m=1 if class== `x'
}
end

global m = "heavy"
dummymaker 4 5 6 8 9 11
replace heavy=0 if heavy==.

global m = "light"
dummymaker 13 14 15 16
replace light=0 if light==.

capture program drop dummymaker


#delimit ;

** Model 2: One year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00  light  (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99 agenew2000), first; 
overid;

** Model 2: One year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00  light  (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00  light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00  light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00  light  (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000), first; 
overid;

** Model 2: Five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00  light  (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 qualcapnew95 skill_labour95 agenew2000), first; 
overid;

**********************************************************************;
display as text "MODEL THREE"                                         ;
**********************************************************************;

** Model 3: One year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99 agenew2000), first; 
overid;

** Model 3: One year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000), first; 
overid;

** Model 3: Five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 light (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 qualcapnew95 skill_labour95 agenew2000), first; 
overid;

log close;
