* Program file of the project "Outsourcing and Firm Productivity" - 4_IABdata06.do
* Contents: Keep necessary variables from the 2006 data set, for analysis on the 2005 year 

* Level of Aggregation:  Firm level IAB data

clear 
set mem 600m

capture log close
log using log/4_IABdata06.log, replace


# delimit ;

use orig/test2006.dta, clear;

** Collect relevant variables from the 2005 IAB panel ;
** Rename variables ;

keep idnum n96b n08 n11 n15 n01ges05 n10 ;

* Change all values to missing, if coded with an -8 or -9 (before data transformations for output, int_investment;
mvdecode _all, mv(-9 -8) ;

* n96b is current industry classification ;

* 2005 output in Euro ;
generate output05 = n08 / 1000 ;
label var output05 "Sales in 2005, in thousands of euros" ; 
drop n08 ;

* Profit in 2005 ; 
rename n11 profitability05 ;
label var profitability05 "Profitability in 2005" ;

* Total business investment in 2005 in Euro;
generate tot_invest05 = n15 / 1000 ; 
label var tot_invest05 "total investment 2005, in thousands of euros" ;
drop n15;

* Total Employees ;
rename n01ges05 emp05 ;
label var emp05 "Employees June 2005" ;

* Intermediate input share of turnover ;
rename n10 intinput05 ;
replace intinput05 = intinput05 / 100 ;
label var intinput05 "Intermediate Inputs Share of Turnover 2005, as percent" ;

* Change all values to missing, if coded with an -8 or -9 ;
mvdecode _all, mv(-9 -8) ;

save data/5_IABdata05.dta, replace ;
sort idnum;

merge idnum using data/3_IABdata05.dta ;
tab _merge;
keep if _merge == 3;
drop _merge;
sort idnum;

* There are some records with all missing values - these are firms that are in both panels but don't have the variables we are interested in;
drop if m95b == .;

* Now, merge in the lag variables;
merge idnum using data/3A_IABdata04 data/3B_IABdata03 ; 
* And drop all observations that don't have data in the year 2005 - we'll use m95b for this ;
drop if m95b == . ;
drop _merge1 _merge2 _merge;


save data/4_IABdata06.dta, replace ;
 
log close ;


