* Program file of the project "Outsourcing and Firm Productivity" - 7_HHIconcordance.do
* Contents: Create variable 'class' for industry classification from the HHI data
*           HHI data is provided by the Monopolkommission, for German manufacturing industries for the odd years 1995 to 2003. Note use 2004 HHI for 2005 data.
*           Generate two measures of HHI to test for robustness, based on different classification groupings
*           See Correspondence with Dr. Gyde Neumann 9/30/2008

* Level of Aggregation:  HHI data is industry level data, organized by European Index NACE (WZ 1993 codes)

clear
set mem 600m

capture log close
log using log/7_HHIconcordance.log, replace

# delimit ;

use orig/HHI.dta, clear ;

rename HHI_1995 HHI_Major95 ;
rename HHI_2000 HHI_Major00 ;
rename HHI_2005 HHI_Major05 ;

* Generate variable class to serve as aggregate industry classification ;

generate class = . ;
label var class "classification of industries" ;
label values class clabel ;

/***********************************************
**   CONCORDANCE and Var Label for HHI_Major  **
***********************************************/

replace class = 1 if wz == "WZ01" ;
label define clabel 1 "agriculture, hunting, forestry and fishing" ;

replace class = 2 if wz == "WZ10" ;
label define clabel 2 "mining and quarrying plus electricity gas water", modify ;

replace class = 3 if wz == "WZ23" ;
label define clabel 3 "Chemicals, coke, refined petroleum, nuclear fuel", modify ;

replace class = 4 if wz == "WZ25" ;
label define clabel 4 "Rubber and Plastic Products", modify ;

replace class = 5 if wz == "WZ26" ;
label define clabel 5 "Other non-metallic products", modify ;

replace class = 6 if wz == "WZ27" ;
label define clabel 6 "Fabricated Metal products, ex machinery", modify ;

replace class = 8 if wz == "WZ29" ;
label define clabel 8 "Machinery", modify ;
 
replace class = 9 if wz == "WZ34" ;
label define clabel 9 "Transport Equipment", modify ;

replace class = 11 if wz == "WZ31" ;
label define clabel 11 "Electrical and Optical Equipment", modify ;

replace class = 13 if wz == "WZ20" ;
label define clabel 13 "Wood products", modify ;

replace class = 14 if wz == "WZ21" ;
label define clabel 14 "Pulp, Paper, PrintPub", modify ;

replace class = 15 if wz == "WZ17" ;
label define clabel 15 "Textiles, Leather, Footwear", modify ;

replace class = 16 if wz == "WZ15" ;
label define clabel 16 "Food Beverage", modify ; 

sort class ;

keep if class !=. ;
keep class HHI_Major95 HHI_Major00 HHI_Major05 ;

save data/7_HHImajor.dta, replace ; 


use orig/HHI.dta, clear ;
rename HHI_1995 HHI_Minor95 ;
rename HHI_2000 HHI_Minor00 ;
rename HHI_2005 HHI_Minor05 ;

* Generate variable class to serve as aggregate industry classification ;

generate class = . ;
label var class "classification of industries" ;
label values class clabel ;

/***********************************************
**   CONCORDANCE and Var Label for HHI_Minor  **
***********************************************/

replace class = 1 if wz == "WZ01" ;
label define clabel 1 "agriculture, hunting, forestry and fishing" ;

replace class = 2 if wz == "WZ11" ;
label define clabel 2 "mining and quarrying plus electricity gas water", modify ;

replace class = 3 if wz == "WZ24" ;
label define clabel 3 "Chemicals, coke, refined petroleum, nuclear fuel", modify ;

replace class = 4 if wz == "WZ25" ;
label define clabel 4 "Rubber and Plastic Products", modify ;

replace class = 5 if wz == "WZ26" ;
label define clabel 5 "Other non-metallic products", modify ;

replace class = 6 if wz == "WZ28" ;
label define clabel 6 "Fabricated Metal products, ex machinery", modify ;

replace class = 8 if wz == "WZ29" ;
label define clabel 8 "Machinery", modify ;
 
replace class = 9 if wz == "WZ35" ;
label define clabel 9 "Transport Equipment", modify ;

replace class = 11 if wz == "WZ33" ;
label define clabel 11 "Electrical and Optical Equipment", modify ;

replace class = 13 if wz == "WZ20" ;
label define clabel 13 "Wood products", modify ;

replace class = 14 if wz == "WZ22" ;
label define clabel 14 "Pulp, Paper, PrintPub", modify ;

replace class = 15 if wz == "WZ19" ;
label define clabel 15 "Textiles, Leather, Footwear", modify ;

replace class = 16 if wz == "WZ15" ;
label define clabel 16 "Food Beverage", modify ; 

sort class ;

keep if class !=. ;
keep class HHI_Minor95 HHI_Minor00 HHI_Minor05 ;

save data/7_HHIminor.dta, replace ; 

log close ;
