* Program file of the project "Outsourcing and Firm Productivity" - 13_Frontier w Klems.do
* Contents: Perform frontier analysis for relevant specifications  

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m

capture log close
log using "log/13_Frontier00 w Klems.log", replace

#delimit ;

use "data/11_FrontierPrep.dta" ; 

*****************************;
* Perfrom Analysis           ;
*****************************;

** Drop industry numbers 13 and 14, and estimate the frontier model ;

****************************;
** Frontier Model Year 2000 ;
****************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;
global L00interact "lnd4L00 lnd5L00 lnd6L00 lnd8L00 lnd9L00 lnd11L00 lnd15L00 lnd16L00" ;
global k00interact "lnd4k1_00 lnd5k1_00 lnd6k1_00 lnd8k1_00 lnd9k1_00 lnd11k1_00 lnd15k1_00 lnd16k1_00" ;

* Analysis with FH measure of Outsourcing ;

capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Major00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Major00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 if year00sample_1==1, nolog noconstant iter(5000) ; 

* Analysis with additiona specifications and FH measure of Outsourcing ;

capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ; 

* Analysis with additional specifications including presence of work council ;

capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;

* Analysis with OECD (direct) measure of Outsourcing ;

capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_2000 HHI_Major00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_narrow_2000 HHI_Major00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_2000 HHI_Minor00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_narrow_2000 HHI_Minor00 if year00sample_1==1, nolog noconstant iter(5000) ; 

* Analysis with additional specifications and OECD (direct) measure of Outsourcing;

capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 if year00sample_1==1, nolog noconstant iter(5000) ; 

* Analysis with additional specifications including presence of works council;

capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;
capture noisily frontier lnva00 $industry $L00interact $k00interact OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_1==1, nolog noconstant iter(5000) ;


log close ;
