* Program file of the project "Outsourcing and Firm Productivity" - 16_Frontier05.do
* Contents: Perform frontier analysis for relevant specifications  

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m

capture log close
log using "log/16_Frontier05 w K_PIMEST.log", replace

#delimit ;

use "data/11_FrontierPrep.dta" ; 

*****************************;
* Perfrom Analysis           ;
*****************************;

** Drop industry numbers 13 and 14, and estimate the frontier model ;


****************************;
** Frontier Model Year 2005 ;
****************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;
global L05interact "lnd4L05 lnd5L05 lnd6L05 lnd8L05 lnd9L05 lnd11L05 lnd15L05 lnd16L05" ;
global k05interact "lnd4k2_05 lnd5k2_05 lnd6k2_05 lnd8k2_05 lnd9k2_05 lnd11k2_05 lnd15k2_05 lnd16k2_05" ;

* Analysis with FH measure of Outsourcing ;

frontier lnva05 $industry $L05interact $k05interact HHI_Major05 FH_OSS_2005 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Major05 FH_OSS_narrow_2005 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 FH_OSS_2005 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 FH_OSS_narrow_2005 if year05sample_2==1, nolog noconstant iter(5000) ;

* Analysis with FH measure of Outsourcing and additional specifications;

frontier lnva05 $industry $L05interact $k05interact HHI_Major05 FH_OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Major05 FH_OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 FH_OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 FH_OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;          

* Analysis with FH measure of Outsourcing and additional specifications including Works Council;

frontier lnva05 $industry $L05interact $k05interact HHI_Major05 FH_OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Major05 FH_OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 FH_OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 FH_OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;          

* Analysis with OECD (direct) measure of Outsourcing ;

frontier lnva05 $industry $L05interact $k05interact HHI_Major05 OSS_2005 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Major05 OSS_narrow_2005 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 OSS_2005 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 OSS_narrow_2005 if year05sample_2==1, nolog noconstant iter(5000) ;

* Analysis with OECD (direct) measure of Outsourcing and additional specifications;

frontier lnva05 $industry $L05interact $k05interact HHI_Major05 OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Major05 OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 if year05sample_2==1, nolog noconstant iter(5000) ;          

* Analysis with OECD (direct) measure of Outsourcing and additional specifications including Works Council;

frontier lnva05 $industry $L05interact $k05interact HHI_Major05 OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Major05 OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 OSS_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;
frontier lnva05 $industry $L05interact $k05interact HHI_Minor05 OSS_narrow_2005 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5000) ;          

log close ;
