* Program file of the project "Outsourcing and Firm Productivity" - 21A_lprod05.do
* Contents: Perform frontier analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m

capture log close
log using log/21AT_lprod05.log, replace

#delimit ;

use data/11_FrontierPrep.dta ; 

*****************************;
* Perform year 2005 Analysis ;
*****************************;

* July 19 2009 correspondence with Sumon Bhaumik ;

* The next question is how we can introduce these in the regression model.                                        ; 
* Let us first deal with performance measures (2)-(4). I think we should introduce the variables in stages:       ;
*                                                                                                                 ;
* (i) performance measure = f(HHI, outsourcing measure)                                                           ;
* (ii) performance measure = g(HHI, outsourcing measure, (a)-(e))                                                 ;
* (iii) performance measure = g(HHI, outsourcing measure, (a)-(f))                                                ;
*                                                                                                                 ; 
* Performance measures generated in Prog/17_FrontierPrep.do (l_prodYY, profit_per_employeeYY, profit_per_salesYY) ;

display as text "                                   " ;
display as text "  Year 2005                        " ;
display as text "                                   " ;
display as text "The Model being summarized         " ;
display as text " is labor productivity             " ;
display as text " using total employment            " ;
display as text "                                   " ;

*******************************************************;
* (i) Regression with outsourcing measures and HHI     ;
*******************************************************;

* FH measure of Outsourcing ;

regress tl_prod05 FH_OSS_2005 HHI_Major05, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05, robust ;

* Direct measure of Outsourcing ;

regress tl_prod05 OSS_2005 HHI_Major05, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05, robust ;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05, robust ;


*******************************************************;
* (ii) Regression with HHI,OSS and specifications      ;
*******************************************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;

* FH measure of Outsourcing and Specifications ;

regress tl_prod05 FH_OSS_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;

regress tl_prod05 FH_OSS_2005 HHI_Major05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 

regress tl_prod05 FH_OSS_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;

* Direct measure of Outsourcing and Specifications;

regress tl_prod05 OSS_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 

* Direct measure of Outsourcing, specifications and LNOUTPUT;

regress tl_prod05 OSS_2005 HHI_Major05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 

* Direct measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction;

regress tl_prod05 OSS_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 

************************************************************************ ******************************************* ;
* (iii) Regression with OSS, HHI, specifications incl. work council, LNOUTPUT and OUTPUT_OUTSOURCING interaction     ;
************************************************************************ ******************************************* ;

* FH measure of Outsourcing, HHI, specifications including work council ;

regress tl_prod05 FH_OSS_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council ;

regress tl_prod05 OSS_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 

* FH measure of Outsourcing, HHI, specifications including works council, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress tl_prod05 FH_OSS_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, LNOUTPUT, OUTPUT_OUTSOURCING interaction;

regress tl_prod05 OSS_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 

*****************************************************************************;
* (iv) Regression with OSS, HHI, specifications incl. work council,          ; 
*       LNOUTPUT, OUTPUT_OUTSOURCING interaction, and industry controls      ;
*****************************************************************************;

* FH measure of Outsourcing, HHI, specifications including works council, industry controls ;

regress tl_prod05 FH_OSS_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, industry controls ;

regress tl_prod05 OSS_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 


* FH measure of Outsourcing, HHI, specifications including works council, industry controls, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress tl_prod05 FH_OSS_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 FH_OSS_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress tl_prod05 FH_OSS_narrow_2005 HHI_Major05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, industry controls, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress tl_prod05 OSS_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 OSS_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress tl_prod05 OSS_narrow_2005 HHI_Major05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress tl_prod05 OSS_narrow_2005 HHI_Minor05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 

log close;