* Program file of the project "Outsourcing and Firm Productivity" - 22A_ppe00.do
* Contents: Perform frontier analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m

capture log close
log using log/22AT_ppe00.log, replace

#delimit ;

use data/11_FrontierPrep.dta ; 

*****************************;
* Perfrom year 2000 Analysis ;
*****************************;

* July 19 2009 correspondence with Sumon Bhaumik ;

* The next question is how we can introduce these in the regression model.                                        ; 
* Let us first deal with performance measures (2)-(4). I think we should introduce the variables in stages:       ;
*                                                                                                                 ;
* (i) performance measure = f(HHI, outsourcing measure)                                                           ;
* (ii) performance measure = g(HHI, outsourcing measure, (a)-(e))                                                 ;
* (iii) performance measure = g(HHI, outsourcing measure, (a)-(f))                                                ;
* 
* Performance measures generated in Prog/17_FrontierPrep.do (l_prodYY, profit_per_employeeYY, profit_per_salesYY) ;

display as text "                                   " ;
display as text "  Year 2000                        " ;
display as text "                                   " ;
display as text "The Model being summarized         " ;
display as text " is profit per employee            " ;
display as text " using total employment            " ;
display as text "                                   " ;

*******************************************************;
* (i) Regression with outsourcing measures and HHI     ;
*******************************************************;

* FH measure of Outsourcing ;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00, robust ;

* Direct measure of Outsourcing ;

regress tprofit_per_emp00 OSS_2000 HHI_Major00, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00, robust ;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00, robust ;


*******************************************************;
* (ii) Regression with HHI,OSS and specifications      ;
*******************************************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;

* FH measure of Outsourcing and Specifications ;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;

* Direct measure of Outsourcing and Specifications;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 

* Direct measure of Outsourcing, specifications and LNOUTPUT;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 

* Direct measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00, robust ; 

************************************************************************ ******************************************* ;
* (iii) Regression with OSS, HHI, specifications incl. work council, LNOUTPUT and OUTPUT_OUTSOURCING interaction     ;
************************************************************************ ******************************************* ;

* FH measure of Outsourcing, HHI, specifications including work council ;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council ;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 

* FH measure of Outsourcing, HHI, specifications including works council, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, LNOUTPUT, OUTPUT_OUTSOURCING interaction;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 

*****************************************************************************;
* (iv) Regression with OSS, HHI, specifications incl. work council,          ; 
*       LNOUTPUT, OUTPUT_OUTSOURCING interaction, and industry controls      ;
*****************************************************************************;

* FH measure of Outsourcing, HHI, specifications including works council, industry controls ;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, industry controls ;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ; 


* FH measure of Outsourcing, HHI, specifications including works council, industry controls, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress tprofit_per_emp00 FH_OSS_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ; 
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Major00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, industry controls, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress tprofit_per_emp00 OSS_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 OSS_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ; 
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Major00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ;
regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 $industry, robust ; 

log close;