* Program file of the project "Outsourcing and Firm Productivity" - 30_lnlprod05_cap1.do
* Contents: Labor Productivity Regression, including measures of capital (based on Klems) per employee

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 605m

capture log close
log using log/30_lnlprod05.log, replace

#delimit ;

use data/11_FrontierPrep.dta ; 

*****************************;
* Perfrom year 2005 Analysis ;
*****************************;

* March 2010 update;

* I think we need to change one of our specifications, the one for labour productivity;
* I was reading up on that literature, and it seems that the prudent thing to do would be ;
* to regress log labour productivity on log capital per labourer and log (raw) materials per labourer;
* (and of course FH_OSS and the others). I am not wedded to the latter variable, and we can drop it if ;
* we do not get good results. ;
* But we do need to keep the log capital per labourer variable in the specification. ;
* Some referees may argue that capital per labourer is endogenous as well. ;
* But at this stage, since we do not have obviously good instruments for that one, let us not worry about it.;

* Note: we do not have raw materials - I use intermediate imports instead;

* July 19 2059 correspondence with Sumon Bhaumik ;

* The next question is how we can introduce these in the regression model.                                        ; 
* Let us first deal with performance measures (2)-(4). I think we should introduce the variables in stages:       ;
*                                                                                                                 ;
* (i) performance measure = f(HHI, outsourcing measure)                                                           ;
* (ii) performance measure = g(HHI, outsourcing measure, (a)-(e))                                                 ;
* (iii) performance measure = g(HHI, outsourcing measure, (a)-(f))                                                ;
* 
* Performance measures generated in Prog/11_FrontierPrep.do (l_prodYY, profit_per_employeeYY, profit_per_salesYY) ;


display as text "                                   " ;
display as text "  Year 2005                        " ;
display as text "                                   " ;
display as text "The Model being summarized         " ;
display as text " is labor productivity             " ;
display as text " using total employment            " ;
display as text " and KLEMS measure of Capital      " ;


*******************************************************;
* (i) Regression with outsourcing measures and HHI     ;
*******************************************************;

* FH measure of Outsourcing ;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05, robust ;

* Direct measure of Outsourcing ;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05, robust ;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05, robust ;


*******************************************************;
* (ii) Regression with HHI,OSS and specifications      ;
*******************************************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;

* FH measure of Outsourcing and Specifications ;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;

* Direct measure of Outsourcing and Specifications;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 

* Direct measure of Outsourcing, specifications and LNOUTPUT;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 

* Direct measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05, robust ; 

************************************************************************ ******************************************* ;
* (iii) Regression with OSS, HHI, specifications incl. work council, LNOUTPUT and OUTPUT_OUTSOURCING interaction     ;
************************************************************************ ******************************************* ;

* FH measure of Outsourcing, HHI, specifications including work council ;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council ;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 

* FH measure of Outsourcing, HHI, specifications including works council, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, LNOUTPUT, OUTPUT_OUTSOURCING interaction;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 

*****************************************************************************;
* (iv) Regression with OSS, HHI, specifications incl. work council,          ; 
*       LNOUTPUT, OUTPUT_OUTSOURCING interaction, and industry controls      ;
*****************************************************************************;

* FH measure of Outsourcing, HHI, specifications including works council, industry controls ;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, industry controls ;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 


* FH measure of Outsourcing, HHI, specifications including works council, industry controls, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress ln_tlprod05 FH_OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 FH_OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;

* Direct measure of Outsourcing, HHI, specifications including works council, industry controls, LNOUTPUT, OUTPUT_OUTSOURCING interaction ;

regress ln_tlprod05 OSS_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 
regress ln_tlprod05 OSS_narrow_2005 HHI_Major05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ;
regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 ln_matemp05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 $industry, robust ; 

log close;