* Program file of the project "Outsourcing and Firm Productivity" - 38_FH_IVregonelag00.do
* Contents: Perform IV regression analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure
*           We use one year lag of endogenous variables, sector and age dummy as instruments

*           This file produces four log files - one for each dependent variable - and two for labor productivity
*             I include both combinations of capital stock for the labor productivity measure, since we can use a one year lag of KLEMS
*             as an instrument.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

*           We include IV regressions for (ii - vi) above, controlling for capqual, skill_labour and lnoutput

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m
set more off

capture log close

#delimit ;

use data/11_FrontierPrep.dta ; 

log using log/38a_FH_IVregonelag_tprofit_per_emp00.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "F; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99 ), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 tprofit_per_emp00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

log close;


log using log/38b_FH_IVregonelag_profit_per_sales00.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "F; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 profit_per_sales00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 profit_per_sales00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99 ), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 profit_per_sales00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 profit_per_sales00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 profit_per_sales00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

log close;

log using log/38c_FH_IVregonelag_lntlprod00_KPIM.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp2_00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp2_00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99 ), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp2_00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp2_00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp2_00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

log close;


log using log/38d_FH_IVregonelag_lntlprod00_KLEMS.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 agenew2000 class qualcapnew99 skill_labour99), first endogtest(ln_capemp1_00 qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 agenew2000 class qualcapnew99 skill_labour99 ), first endogtest(ln_capemp1_00 qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 lnoutput00 = ln_capemp1_99 agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(ln_capemp1_00 qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 lnoutput00 = ln_capemp1_99 agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(ln_capemp1_00 qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 lnoutput00 = ln_capemp1_99 agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(ln_capemp1_00 qualcapnew00 skill_labour00 lnoutput00);
overid;

log close;

log using log/38e_FH_IVregonelag_lntlprod00_KLEMS_noK_IV.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV without K IV";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp1_00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions without K IV";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp1_00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 = agenew2000 class qualcapnew99 skill_labour99 ), first endogtest(qualcapnew00 skill_labour00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput without K IV";
display as text "            ";    
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 ln_capemp1_00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction without K IV";
display as text "            ";  
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 ln_capemp1_00 eastgerman00 foreign00 public00 other00 workcouncnew00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions without K IV";
display as text "            ";  
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 FH_OSS_output00 ln_capemp1_00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (qualcapnew00 skill_labour00 lnoutput00 = agenew2000 class qualcapnew99 skill_labour99 lnoutput99), first endogtest(qualcapnew00 skill_labour00 lnoutput00);
overid;


log close;

