* Program file of the project "Outsourcing and Firm Productivity" - 38_Frontier00_estout.do
* Contents: Perform frontier analysis for relevant specifications  

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m

capture log close
log using "log/38_Frontier00_estout w K_PIMEST.log", replace

#delimit ;

use "data/11_FrontierPrep.dta" ; 

*****************************;
* Perfrom Analysis           ;
*****************************;

** Drop industry numbers 13 and 14, and estimate the frontier model ;

****************************;
** Frontier Model Year 2000 ;
****************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;
global L00interact "lnd4L00 lnd5L00 lnd6L00 lnd8L00 lnd9L00 lnd11L00 lnd15L00 lnd16L00" ;
global k00interact "lnd4k2_00 lnd5k2_00 lnd6k2_00 lnd8k2_00 lnd9k2_00 lnd11k2_00 lnd15k2_00 lnd16k2_00" ;

* Analysis with FH measure of Outsourcing ;

eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 if year00sample_2==1, nolog noconstant iter(5000) ;
eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 if year00sample_2==1, nolog noconstant iter(5000) ; 

* Analysis with additional specifications including presence of work council ;

eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_2==1, nolog noconstant iter(5000) ;
eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_2==1, nolog noconstant iter(5000) ;

* Analysis with additional specifications and lnoutput ;

eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 lnoutput00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_2==1, nolog noconstant iter(5000) ;
eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_2==1, nolog noconstant iter(5000) ;

* Analysis with additional specifications, lnoutput and lnoutput*oss interaction;

eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_2==1, nolog noconstant iter(5000) ;
eststo: capture noisily frontier lnva00 $industry $L00interact $k00interact FH_OSS_narrow_2000 HHI_Minor00 lnoutput00 FH_OSS_output00 agenew2000 qualcapnew00 eastgerman00 foreign00 public00 other00 workcouncnew00 if year00sample_2==1, nolog noconstant iter(5000) ;


* Output models to table form in a text file;
estout est1 est2 est3 est4 est5 est6 est7 est8 using "log/Frontier00_Table1.xls", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 1: Frontier Model, year 2000); 


log close ;
