* Program file of the project "Outsourcing and Firm Productivity" - 39_Frontier05_estout.do
* Contents: Perform frontier analysis for relevant specifications  

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 605m

capture log close
log using "log/39_Frontier05_estout w K_PIMEST.log", replace

#delimit ;

use "data/11_FrontierPrep.dta" ; 

*****************************;
* Perfrom Analysis           ;
*****************************;

** Drop industry numbers 13 and 14, and estimate the frontier model ;

****************************;
** Frontier Model Year 2005 ;
****************************;

global industry "d4 d5 d6 d8 d9 d11 d15 d16" ;
global L05interact "lnd4L05 lnd5L05 lnd6L05 lnd8L05 lnd9L05 lnd11L05 lnd15L05 lnd16L05" ;
global k05interact "lnd4k2_05 lnd5k2_05 lnd6k2_05 lnd8k2_05 lnd9k2_05 lnd11k2_05 lnd15k2_05 lnd16k2_05" ;

* Analysis with FH measure of Outsourcing ;

eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_2005 HHI_Minor05 if year05sample_2==1, nolog noconstant iter(5050) ;
eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_narrow_2005 HHI_Minor05 if year05sample_2==1, nolog noconstant iter(5050) ; 

* Analysis with additional specifications including presence of work council ;

eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_2005 HHI_Minor05 agenew2005 qualcapnew05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5050) ;
eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_narrow_2005 HHI_Minor05 agenew2005 qualcapnew05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5050) ;

* Analysis with additional specifications and lnoutput ;

eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_2005 HHI_Minor05 lnoutput05 agenew2005 qualcapnew05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5050) ;
eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 agenew2005 qualcapnew05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5050) ;

* Analysis with additional specifications, lnoutput and lnoutput*oss interaction;

eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5050) ;
eststo: capture noisily frontier lnva05 $industry $L05interact $k05interact FH_OSS_narrow_2005 HHI_Minor05 lnoutput05 FH_OSS_output05 agenew2005 qualcapnew05 eastgerman05 foreign05 public05 other05 workcouncnew05 if year05sample_2==1, nolog noconstant iter(5050) ;


* Output models to table form in a text file;
estout est1 est2 est3 est4 est5 est6 est7 est8 using "log/Frontier05_Table2.xls", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 2: Frontier Model, year 2005); 


log close ;
