* Program file of the project "Outsourcing and Firm Productivity" - 40_FH_IVregonelag05.do
* Contents: Perform IV regression analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure
*           We use one year lag of endogenous variables, sector and age dummy as instruments

*           This file produces four log files - one for each dependent variable - and two for labor productivity
*             I include both combinations of capital stock for the labor productivity measure, since we can use a one year lag of KLEMS
*             as an instrument.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

*           We include IV regressions for (ii - vi) above, controlling for capqual, skill_labour and lnoutput

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m
set more off

capture log close

#delimit ;

use data/11_FrontierPrep.dta ; 

log using log/40a_FH_IVregonelag_tprofit_per_emp05.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 tprofit_per_emp05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 tprofit_per_emp05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04 ), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 tprofit_per_emp05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput99), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 tprofit_per_emp05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 tprofit_per_emp05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

log close;

log using log/40b_FH_IVregonelag_profit_per_sales05.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 profit_per_sales05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 profit_per_sales05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04 ), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 profit_per_sales05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput99), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 profit_per_sales05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 profit_per_sales05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

log close;


log using log/40c_FH_IVregonelag_lntlprod05_KPIM.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp2_05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp2_05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04 ), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp2_05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp2_05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp2_05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

log close;


log using log/40d_FH_IVregonelag_lntlprod05_KLEMS.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_04 agenew2005 class qualcapnew03 skill_labour04), first endogtest(ln_capemp1_05 qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus foreign,union interactions ";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_04 agenew2005 class qualcapnew03 skill_labour04 ), first endogtest(ln_capemp1_05 qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus lnoutput";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 public05 other05 workcouncnew05 (ln_capemp1_05 qualcapnew05 skill_labour05 lnoutput05 = ln_capemp1_04 agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(ln_capemp1_05 qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus FH_OSS_output interaction";
display as text "            ";  
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 (ln_capemp1_05 qualcapnew05 skill_labour05 lnoutput05 = ln_capemp1_04 agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(ln_capemp1_05 qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS broad IV plus oss_output, foreign and union interactions";
display as text "            ";  
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (ln_capemp1_05 qualcapnew05 skill_labour05 lnoutput05 = ln_capemp1_04 agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(ln_capemp1_05 qualcapnew05 skill_labour05 lnoutput05);
overid;

log close;

log using log/40e_FH_IVregonelag_lntlprod05_KLEMS_noK_IV.log, replace;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS IV, no capemp as IV";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS  IV plus foreign,union interactions, no capemp as IV ";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 = agenew2005 class qualcapnew03 skill_labour04 ), first endogtest(qualcapnew05 skill_labour05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS  IV plus lnoutput, no capemp as IV";
display as text "            ";    
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 ln_capemp1_05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS  IV plus FH_OSS_output interaction, no capemp as IV";
display as text "            ";  
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 ln_capemp1_05 eastgerman05 foreign05 public05 other05 workcouncnew05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

display as text "            "; 
display as text "            "; 
display as text "            "; 
display as text "FH OSS  IV plus oss_output, foreign and union interactions, no capemp as IV";
display as text "            ";  
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 FH_OSS_output05 ln_capemp1_05 eastgerman05 foreign05 public05 other05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 (qualcapnew05 skill_labour05 lnoutput05 = agenew2005 class qualcapnew03 skill_labour04 lnoutput04), first endogtest(qualcapnew05 skill_labour05 lnoutput05);
overid;

log close;

