* Program file of the project "Outsourcing and Firm Productivity" - 42_estout_OSS_reg00.do
* Contents: Use the estout ado package to create tables for regression specifications for three dependent variables in yr2000
*  Note: See "http://repec.org/bocode/e/estout/index.html" for documentation on estout command.
*        See "http://www.ats.ucla.edu/stat/stata/faq/estout.htm" for easy to follow examples on using estout command.
*
*  Note: The estout command outputs tables to excel format, but excel interprets the ( ) around standard errors and p-values
*         as negative numbers.  It is necessary to 'format cells' so that negative numbers are in ().
*  Note:  The estout command also will NOT write over an old output table.  So, if we submit this code to IAB more than once,
*          It is necessary to change the table name in the 'using' command in the estout line.  There are THREE 'using' commands below.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

* Note: ESTOUT Command commented out on May 21 - Work with IAB to find acceptable program code if we want to go down this route at a later date


clear 
set mem 600m

capture log close
log using log/42_estout_OSS_reg00.log, replace

#delimit ;

use data/11_FrontierPrep.dta ; 
eststo clear;

*****************************;
* Perfrom year 2000 Analysis ;
*****************************;

*******************************************************;
* (i) Table 1: Labour Productivity with PIM est K      ;
*      This is our preferred (?) measure               ;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp2_00 , robust ; 
eststo: regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp2_00 , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp2_00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp2_00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp2_00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp2_00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp2_00  lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp2_00  lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp2_00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp2_00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp2_00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp2_00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/LNlprod00_Table1_OSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 1: Log Output per Emp,K PIM, year 2000, OSS measure); 

eststo clear;


*******************************************************;
* (ia) Table 1A: Labour Productivity with Klems est of K;
*      This measure allows for lags in IV specification;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp1_00 , robust ; 
eststo: regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp1_00 , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp1_00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp1_00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp1_00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp1_00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp1_00  lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp1_00  lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp1_00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp1_00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress ln_tlprod00 OSS_2000 HHI_Minor00 ln_capemp1_00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress ln_tlprod00 OSS_narrow_2000 HHI_Minor00 ln_capemp1_00 lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/LNlprod00_Table1A_KlemsOSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 1A: Log Output per Emp, KLEMS, year 2000, OSS measure); 

eststo clear;


*******************************************************;
* (ii) Table 3: Profit Per Sales                        ;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress profit_per_sales00 OSS_2000 HHI_Minor00  , robust ; 
eststo: regress profit_per_sales00 OSS_narrow_2000 HHI_Minor00  , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress profit_per_sales00 OSS_2000 HHI_Minor00   agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress profit_per_sales00 OSS_narrow_2000 HHI_Minor00   agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress profit_per_sales00 OSS_2000 HHI_Minor00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress profit_per_sales00 OSS_narrow_2000 HHI_Minor00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress profit_per_sales00 OSS_2000 HHI_Minor00   lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress profit_per_sales00 OSS_narrow_2000 HHI_Minor00   lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress profit_per_sales00 OSS_2000 HHI_Minor00   lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress profit_per_sales00 OSS_narrow_2000 HHI_Minor00   lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress profit_per_sales00 OSS_2000 HHI_Minor00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress profit_per_sales00 OSS_narrow_2000 HHI_Minor00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/PPS00_Table3_OSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 3: Profit per Sales, year 2000, OSS measure); 

eststo clear;


*******************************************************;
* (iii) Table 5: Profit per Employee                     ;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress tprofit_per_emp00 OSS_2000 HHI_Minor00  , robust ; 
eststo: regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00  , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress tprofit_per_emp00 OSS_2000 HHI_Minor00   agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00   agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress tprofit_per_emp00 OSS_2000 HHI_Minor00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00  agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress tprofit_per_emp00 OSS_2000 HHI_Minor00   lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00   lnoutput00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress tprofit_per_emp00 OSS_2000 HHI_Minor00   lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ; 
eststo:  regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00   lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress tprofit_per_emp00 OSS_2000 HHI_Minor00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ; 
eststo:  regress tprofit_per_emp00 OSS_narrow_2000 HHI_Minor00  lnoutput00 OSS_output00 agenew2000 qualcapnew00 skill_labour00 eastgerman00 foreign00 public00 other00 workcouncnew00 OSS_ownership00 OSS_union00, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/PPE00_Table5_OSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 5: Profit per Emp, year 2000, OSS measure); 

eststo clear;


log close;
