* Program file of the project "Outsourcing and Firm Productivity" - 43_estout_OSS_reg05.do
* Contents: Use the estout ado package to create tables for regression specifications for three dependent variables in yr2005
*  Note: See "http://repec.org/bocode/e/estout/index.html" for documentation on estout command.
*        See "http://www.ats.ucla.edu/stat/stata/faq/estout.htm" for easy to follow examples on using estout command.
*
*  Note: The estout command outputs tables to excel format, but excel interprets the ( ) around standard errors and p-values
*         as negative numbers.  It is necessary to 'format cells' so that negative numbers are in ().
*  Note:  The estout command also will NOT write over an old output table.  So, if we submit this code to IAB more than once,
*          It is necessary to change the table name in the 'using' command in the estout line.  There are THREE 'using' commands below.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

* Note: ESTOUT Command commented out on May 21 - Work with IAB to find acceptable program code if we want to go down this route at a later date

clear 
set mem 605m

capture log close
log using log/43_estout_OSS_reg05.log, replace

#delimit ;

use data/11_FrontierPrep.dta ; 
eststo clear;

*****************************;
* Perfrom year 2005 Analysis ;
*****************************;

*******************************************************;
* (i) Table 2: Labour Productivity                     ;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp2_05 , robust ; 
eststo: regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp2_05 , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp2_05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp2_05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp2_05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp2_05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp2_05  lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp2_05  lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp2_05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp2_05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp2_05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp2_05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/LNlprod05_Table2_OSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 2: Log Output per Emp, K PIM, year 2005, OSS); 

eststo clear;

*******************************************************;
* (ia) Table 2A: Labour Productivity with Klems est of K;
*      This measure allows for lags in IV specification;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 , robust ; 
eststo: regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05  lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05  lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress ln_tlprod05 OSS_2005 HHI_Minor05 ln_capemp1_05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress ln_tlprod05 OSS_narrow_2005 HHI_Minor05 ln_capemp1_05 lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/LNlprod05_Table2A_KlemsOSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 2A: Log Output per Emp, KLEMS, year 2005, OSS); 

eststo clear;


*******************************************************;
* (ii) Table 4: Profit Per Sales                        ;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress profit_per_sales05 OSS_2005 HHI_Minor05  , robust ; 
eststo: regress profit_per_sales05 OSS_narrow_2005 HHI_Minor05  , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress profit_per_sales05 OSS_2005 HHI_Minor05   agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress profit_per_sales05 OSS_narrow_2005 HHI_Minor05   agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress profit_per_sales05 OSS_2005 HHI_Minor05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress profit_per_sales05 OSS_narrow_2005 HHI_Minor05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress profit_per_sales05 OSS_2005 HHI_Minor05   lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress profit_per_sales05 OSS_narrow_2005 HHI_Minor05   lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress profit_per_sales05 OSS_2005 HHI_Minor05   lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress profit_per_sales05 OSS_narrow_2005 HHI_Minor05   lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress profit_per_sales05 OSS_2005 HHI_Minor05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress profit_per_sales05 OSS_narrow_2005 HHI_Minor05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/PPS05_Table4_OSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 4: Profit per Sales, year 2005, OSS); 

eststo clear;


*******************************************************;
* (iii) Table 6: Profit per Employee                     ;
*******************************************************;

* FH measure of Outsourcing ;
eststo: regress tprofit_per_emp05 OSS_2005 HHI_Minor05  , robust ; 
eststo: regress tprofit_per_emp05 OSS_narrow_2005 HHI_Minor05  , robust ;

* FH measure of Outsourcing and Specifications ;
eststo:  regress tprofit_per_emp05 OSS_2005 HHI_Minor05   agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress tprofit_per_emp05 OSS_narrow_2005 HHI_Minor05   agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, Specifications and interactions ;
eststo:  regress tprofit_per_emp05 OSS_2005 HHI_Minor05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress tprofit_per_emp05 OSS_narrow_2005 HHI_Minor05  agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* FH measure of Outsourcing, Specifications, and LNOUTPUT;
eststo:  regress tprofit_per_emp05 OSS_2005 HHI_Minor05   lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress tprofit_per_emp05 OSS_narrow_2005 HHI_Minor05   lnoutput05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and OUTPUT_OUTSOURCING interaction; 
eststo:  regress tprofit_per_emp05 OSS_2005 HHI_Minor05   lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ; 
eststo:  regress tprofit_per_emp05 OSS_narrow_2005 HHI_Minor05   lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05, robust ;

* FH measure of Outsourcing, specifications, LNOUTPUT and all interactions; 
eststo:  regress tprofit_per_emp05 OSS_2005 HHI_Minor05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ; 
eststo:  regress tprofit_per_emp05 OSS_narrow_2005 HHI_Minor05  lnoutput05 OSS_output05 agenew2005 qualcapnew05 skill_labour05 eastgerman05 foreign05 public05 other05 workcouncnew05 OSS_ownership05 OSS_union05, robust ;

* Output models to table form in a text file;
*estout est1 est2 est3 est4 est5 est6 est7 est8 est9 est10 est11 est12 using "log/PPE05_Table6_OSS.txt", cells(b(star fmt(4)) se(par fmt(4)) p(par)) ///
    stats(r2 F p df_r N, fmt(3 2 4 0 0) label(R-squared "F-stat" "Prob > F" "Degrees Freedom" "N. of obs")) starlevels(* 0.10 ** 0.05 *** 0.01) /// 
    legend varlabels(_cons constant) title(Table 6: Profit per Emp, year 2005, OSS); 

eststo clear;


log close;
