* Program file of the project "Outsourcing and Firm Productivity" - 51_FH_IVreg_lntlprod05_instruments_industrycontrols.do
* Contents: Perform IV regression analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure
*           We use one and five year lag of endogenous variables, and age dummy as instruments

*           
*             I include both combinations of capital stock for the labor productivity measure, since we can use a one year lag of KLEMS
*             as an instrument.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, industry dummies
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, industry dummies, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, industry dummies, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, industry dummies, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, industry dummies, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

*           We include IV regressions for (ii - vi) above, controlling for capqual, skill_labour and lnoutput

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear
clear matrix
set mem 600m
set more off

capture log close



use data/11_FrontierPrep.dta

log using log/51_FH_IVreg_lntlprod05_instruments_industrycontrols.log, replace


*6/30/2010- Results of the new regressions using "light" as an instrument came back unsatisfactory, the specifications continue to fail the Sargan test.
*Sumon has suggested that we try using n-1 industry indicator variables in the main specification rather than as instruments. Therefore, the following 
*code constructs individual industry dummys. 

foreach num of numlist 4 5 6 8 9 11 13 14 15 16 {
gen in`num'=.
}


foreach num of numlist 4 5 6 8 9 11 13 14 15 16 {
		replace in`num'=1 if class== `num'
}

foreach num of numlist 4 5 6 8 9 11 13 14 15 16 {
		replace in`num'=0 if in`num'==.
}

local in = "in4 in5 in6 in8 in9 in11 in13 in14 in15"



#delimit ;

** Model 2: One year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_04 qualcapnew03 skill_labour04 agenew2005), first; 
overid;

** Model 2: One year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_04 qualcapnew03 skill_labour04), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 ln_capemp1_04 qualcapnew00 qualcapnew03 skill_labour00 skill_labour04 agenew2005), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 ln_capemp1_04 qualcapnew00 qualcapnew03 skill_labour00 skill_labour04), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 `in'  (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 ln_capemp1_04 qualcapnew00 qualcapnew03 skill_labour00 skill_labour04 agenew2005), first; 
overid;

** Model 2: Five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 qualcapnew00 skill_labour00 agenew2005), first; 
overid;

**********************************************************************;
display as text "MODEL THREE"                                         ;
**********************************************************************;

** Model 3: One year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_04 qualcapnew03 skill_labour04 agenew2005), first; 
overid;

** Model 3: One year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_04 qualcapnew03 skill_labour04), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 ln_capemp1_04 qualcapnew00 qualcapnew03 skill_labour00 skill_labour04 agenew2005), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual, and skill_labour;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 ln_capemp1_04 qualcapnew00 qualcapnew03 skill_labour00 skill_labour04), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 ln_capemp1_04 qualcapnew00 qualcapnew03 skill_labour00 skill_labour04 agenew2005), first; 
overid;

** Model 3: Five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod05 FH_OSS_2005 HHI_Minor05 eastgerman05 foreign05 workcouncnew05 FH_OSS_ownership05 FH_OSS_union05 `in' (ln_capemp1_05 qualcapnew05 skill_labour05 = ln_capemp1_00 qualcapnew00 skill_labour00 agenew2005), first; 
overid;

log close;
