* Program file of the project "Outsourcing and Firm Productivity" - 12_Summarize.do
* Contents: Use Summarize command to create summary statistics of all RHS independent variables.  
*            Summary of LHS variables is at the end of the file, outside of the foreach loop.
*            Create Density plots of all LHS variables.
*           NOTE: As of May 13, 2010 We have not created a density plot for LN(Output/Employees) 
*             This is the variable ln_tlprod00 and ln_tlprod05

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

set more off

clear 
set mem 600m

capture log close
log using log/12_Summarize.log, replace

#delimit ;

use "data/11_FrontierPrep.dta" ;

/* Our broad goal here is to create summary statistics only for the observations that will be included in the model             */;
/* We restrict on the broadest (model 1) that includes dep var = OSS HHI error term                                             */;
/* Since all outsourcing and HHI variables are matched at the Industry level, we only need to include one variable, here OSS_YY */;

* Frontier dummy 1 uses the Klems measure of capital stock; 
* Frontier dummy 2 uses the G est measure of capital stock;

generate frontier1_00_dummy = 1 if lnva00 !=. & lncap1_00 !=. & lnlabor00 !=. ;
generate frontier1_05_dummy = 1 if lnva05 !=. & lncap1_05 !=. & lnlabor05 !=. ; 

generate frontier2_00_dummy = 1 if lnva00 !=. & lncap2_00 !=. & lnlabor00 !=. ;
generate frontier2_05_dummy = 1 if lnva05 !=. & lncap2_05 !=. & lnlabor05 !=. ; 

generate l_prod00_dummy = 1 if tl_prod00 !=. & OSS_2000 !=. ;
generate l_prod05_dummy = 1 if tl_prod05 !=. & OSS_2005 !=. ;

generate ppe00_dummy = 1 if tprofit_per_emp00 !=. & OSS_2000 !=. ;
generate ppe05_dummy = 1 if tprofit_per_emp05 !=. & OSS_2005 !=. ;

generate pps00_dummy = 1 if profit_per_sales00 != . & OSS_2000 !=. ;
generate pps05_dummy = 1 if profit_per_sales05 != . & OSS_2005 !=. ;

local models "frontier1_ frontier2_ l_prod ppe pps" ;

foreach x of local models {             ;

display as text "                                   " ;
display as text "  Year 2000                        " ;
display as text "                                   " ;
display as text "The Model being summarized is `x': " ;
display as text "                                   " ;
display as text "                                   " ;
display as text "                                   " ;

** Measures of firm size ;
summarize output00 output99 output95 if `x'00_dummy == 1, detail;

** Measures of Capital Stock, Value Added and Labor ;
summarize lnva00 lnlabor00 lncap1_00 lncap2_00 if `x'00_dummy == 1, detail ; 

** Measures of Outsourcing ;
summarize OSS_2000 OSS_narrow_2000 FH_OSS_2000 FH_OSS_narrow_2000 if `x'00_dummy == 1, detail ; 

** Measures of Herfindahl Index ;
summarize HHI_Major00 HHI_Minor00 if `x'00_dummy == 1, detail ;

** Measures of Profit, Output and Intermediate Input ;
summarize profit00 profitability00 output00 intinput00 if `x'00_dummy == 1, detail ;

** Additional Measures for labor productivity;
summarize ln_tlprod00 ln_capemp1_00 ln_capemp2_00 if `x'00_dummy == 1, detail;

** YR 2000 Additional Specifications ;
summarize eastgerman00 foreign00 public00 other00 workcouncnew00 if `x'00_dummy == 1, detail ;
summarize agenew2000 age2000 ln_capemp1_99 ln_capemp1_95 qualcapnew00 qualcapnew99 qualcapnew95 skill_labour00 skill_labour99 skill_labour95 if `x'00_dummy == 1, detail ;

** YR 2000 Interactions ;
summarize lnoutput00 FH_OSS_output00 OSS_output00 FH_OSS_ownership00 OSS_ownership00 FH_OSS_union00 OSS_union00 if `x'00_dummy == 1, detail ;

display as text "                                   " ;
display as text "  Year 2005                        " ;
display as text "                                   " ;
display as text "The Model being summarized is `x': " ;
display as text "                                   " ;
display as text "                                   " ;
display as text "                                   " ;

** Measures of firm size ;
summarize output05 output04 output00 if `x'05_dummy == 1, detail;

** Measures of Capital Stock ;
summarize Klems05 K_PIMEST_05 if `x'05_dummy == 1, detail ; 

** Measures of Capital Stock, Value Added and Labor ;
summarize lnva05 lnlabor05 lncap1_05 lncap2_05 if `x'05_dummy == 1, detail ; 

** Measures of Outsourcing ;
summarize OSS_2005 OSS_narrow_2005 FH_OSS_2005 FH_OSS_narrow_2005 if `x'05_dummy == 1, detail;

** Measures of Herfindahl Index;
summarize HHI_Major05 HHI_Minor05 if `x'05_dummy == 1, detail ;

** Measures of Profit, Output and Intermediate Input  ;
summarize profit05 profitability05 output05 intinput05 if `x'05_dummy == 1, detail ;

** Additional Measures for labor productivity;
summarize ln_tlprod05 ln_capemp1_05 ln_capemp2_05 if `x'05_dummy == 1, detail;

** YR 2005 Additional Specifications ;
summarize eastgerman05 foreign05 public05 other05 workcouncnew05 if `x'05_dummy == 1, detail ;
summarize agenew2005 age2005 ln_capemp1_04 ln_capemp1_00 qualcapnew05 qualcapnew03 qualcapnew00 skill_labour05 skill_labour04 skill_labour00 if `x'05_dummy == 1, detail ;

** YR 2005 Interactions ;
summarize lnoutput05 FH_OSS_output05 OSS_output05 FH_OSS_ownership05 OSS_ownership05 FH_OSS_union05 OSS_union05 if `x'05_dummy == 1, detail ; 

}  ;

** LHS Variables ;
** NOTE: NEED TO SUBMIT CODE WITH ln_tlprod00 and ln_tlprod05 in the local models loop below;
**        As of may 13 2010;

summarize tl_prod00 if l_prod00_dummy == 1, detail;
summarize tprofit_per_emp00 if ppe00_dummy == 1, detail;
summarize profit_per_sales00 if pps00_dummy == 1, detail ; 

summarize tl_prod05 if l_prod05_dummy == 1, detail;
summarize tprofit_per_emp05 if ppe05_dummy == 1, detail;
summarize profit_per_sales05 if pps05_dummy == 1, detail ; 

** Generate KDensity Graphs of the LHS Variables and save to a new folder;

local models "lnva tl_prod tprofit_per_emp profit_per_sales ln_tlprod" ;

foreach x of local models {                                    ;       
	twoway (kdensity `x'00),title("Kdensity plot of `x'00") name(`x'00, replace);
	graph export log/`x'00.eps, replace;

	twoway (kdensity `x'05),title("Kdensity plot of `x'05") name(`x'05, replace);
	graph export log/`x'05.eps, replace;
};


log close;
