* Program file of the project "Outsourcing and Firm Productivity" - 48_FH_IVreg_lntlprod00_instruments.do
* Contents: Perform IV regression analysis for relevant specifications  
*           Check for Robustness of Total Employee Measure
*           We use one and five year lag of endogenous variables, sector and age dummy as instruments

*           This file produces four log files - one for each dependent variable - and two for labor productivity
*             I include both combinations of capital stock for the labor productivity measure, since we can use a one year lag of KLEMS
*             as an instrument.

*           Within each dependent variable, we have 6 sets of specifications:
*            (i)   depvar = outsourcing, HHI
*            (ii)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union
*            (iii) depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, ownership*outsourcing, union*outsourcing
*            (iv)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput
*            (v)   depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction
*            (vi)  depvar = outsourcing, HHI, age, capqual, skill_labour, ownership, union, lnoutput, output*OSS interaction, ownership*outourcing interaction, union*outsourcing interaction

*           We include IV regressions for (ii - vi) above, controlling for capqual, skill_labour and lnoutput

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
set mem 600m
set more off

capture log close

#delimit ;

use data/11_FrontierPrep.dta ; 

log using log/48_FH_IVreg_lntlprod00_instruments.log, replace;

** Model 2: One year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99 agenew2000), first; 
overid;

** Model 2: One year lag of cap/emp capqual skill_labour, and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99 class), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 class), first; 
overid;

** Model 2: One and five year lag of cap/emp capqual skill_labour, age and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000 class), first; 
overid;

** Model 2: Five year lag of cap/emp capqual skill_labour, age and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 qualcapnew95 skill_labour95 agenew2000 class), first; 
overid;

**********************************************************************;
display as text "MODEL THREE"                                         ;
**********************************************************************;

** Model 3: One year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99 agenew2000), first; 
overid;

** Model 3: One year lag of cap/emp capqual skill_labour, and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_99 qualcapnew99 skill_labour99 class), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, and age;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 class), first; 
overid;

** Model 3: One and five year lag of cap/emp capqual skill_labour, age and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 ln_capemp1_99 qualcapnew95 qualcapnew99 skill_labour95 skill_labour99 agenew2000 class), first; 
overid;

** Model 3: Five year lag of cap/emp capqual skill_labour, age and sector;
ivreg2 ln_tlprod00 FH_OSS_2000 HHI_Minor00 eastgerman00 foreign00 public00 other00 workcouncnew00 FH_OSS_ownership00 FH_OSS_union00 (ln_capemp1_00 qualcapnew00 skill_labour00 = ln_capemp1_95 qualcapnew95 skill_labour95 agenew2000 class), first; 
overid;

log close;
