clear
set more off
capture log close
log using OSS.log, replace

foreach y of global YEAR {

use master`y', clear

**********************************************************************
** Remember that FH_IMPINT is a N x 1 matrix of import intensity    **
** by industry.  Each observation matches up with the corresponding **
** industry weight.                                                 **
**********************************************************************
 
matrix FH_OSS = J(48,48,0)

forvalues i = 1(1)48 {
  forvalues j = 1(1)48 {
    matrix FH_OSS[`i',`j'] = w[`i',`j'] * FH[`i',`j']
   }
  }

**********************************************************************
** The wide measure of outsourcing looks at all inputs into a given **
** industry.  This is the column sum.                               **
** We follow the same idea as in 'Total_Purchase.Do'                **
** Transpose the matrix OSS, sum across rows                        **
**********************************************************************

matrix FH_OSST = FH_OSS'
svmat FH_OSST, names(col)

egen FH_OSS_WIDE = rowtotal(r1-r48)
drop r1-r48


**********************************************************************
** OSS and OSS_Wide now both make up a 48 x 48 square matrix        **
** I use this property to easily make two column vectors            **
** for the variables OSS_wide and OSS_narrow using the vecdiag()    **
** function, which takes the diagonal and makes a column vector.    **
** The column vectors can be more easily worked with in excel or in **
** regressions in Stata.                                            **
**********************************************************************

matrix FH_OSS_narrow = vecdiag(FH_OSS)
matrix FH_OSS_Narrow = FH_OSS_narrow'
svmat FH_OSS_Narrow, name(FH_OSS_Narrow)


******************************************
** Amiti and Wei (2004) measures of OSS **
******************************************
** Note this notation might seem slightly confusing
** AW_IMPINT is a 36 X 1 matrix, where cell(1,1) is industry 1, cell(2,1) is industry 2, etc.
** We want to multiply all of the weights for industry i (the column) by the corresponding AW_IMPINT cell
** The use of `i'  fixes the column headings to accomplish this goal

mkmat AW_IMPINT, matrix(AW_IMPINT)
 
matrix AW_OSS = J(48,48,0)

forvalues i = 1(1)48 {
  forvalues k = 1(1)48 {
    matrix AW_OSS[`k',`i'] = w[`k',`i'] * AW_IMPINT[`i',1]
   }
  }

matrix AW_OSST = AW_OSS'
svmat AW_OSST, names(col)

egen AW_OSS_WIDE = rowtotal(r1-r48)
drop r1-r48

matrix AW_OSS_narrow = vecdiag(AW_OSS)
matrix AW_OSS_Narrow = AW_OSS_narrow'
svmat AW_OSS_Narrow, name(AW_OSS_Narrow)


********************************
** Save and Output the Data   **
********************************

save master`y', replace

keep isicn industry FH_OSS_WIDE FH_OSS_Narrow AW_OSS_WIDE AW_OSS_Narrow

save OSS_results_`y', replace

outsheet using OSS_results_`y', replace
}

log close
exit
