clear
capture log close
log using total_purchase.log, replace

set more off

foreach y of global YEAR {

use master`y', clear

***************************************************************
** Domestic production is defined in the 'GetData.do' file   **
***************************************************************

generate FH_IMPINT = total_intermediate_import / domesticproduction

***************************************************************
** This generates the total non energy inputs by industry i  **
** By creating a matrix, transposing the data and creating   **
** new variables r1 - r48.  Stata operates by rows.  Thus,   **
** Summing up variables r1 thru 48 is now the same operation **
** as summing up the variable t1 (the column of total inputs **
** for ISICN industry 1                                      **
***************************************************************

mkmat t1-t48, matrix(T)

*** Transpose the data

matrix t = T'

*** The command svmatt turns the matrix T into a series of variables, with the columns named r1 thr r48.  
***  Each number corresponds to the industry.  That is, r1 entry 2 is input into industry two. 

svmat t, names(col)


*** Total purchases exclude the industries 2, 8, 26, 27, 28 
*** This drops the following industries involved in energy production:
*** Mining/Quaryying (energy), Coke/Refined Petroleum, Electricity, Gas, Steam

generate total_purchase =  r1 + r3 + r4 + r5 +r6 +r7 +r9 +r10 +r11 +r12 +r13 +r14 +r15 +r16 +r17 +r18 + r19 +r20 +r21 +r22 +r23 +r24 +r25 +r29+r30+r31+r32+r33+r34+r35+r36+r37+r38+r39+r40+r41+r42+r43+r44+r45+r46+r47+r48

drop r1-r48

*****************************************************************
** The following steps use loops to process like industries    **
** The next step also calculates total_purchase for industry i **
** In this set up, tota_purchase`i' will be equal to the `i'   **
** observation in the variable total_purchase created above.   **
** This serves as a check that the two different summation     **
** procedures work as expected.                                **
*****************************************************************

forvalues i = 1(1)48 {
 quietly summarize t`i'
 generate total_purchase`i' = r(sum) - t`i'[_N - 46] - t`i'[_N - 40 ] - t`i'[_N - 22 ] - t`i'[_N - 21 ] - t`i'[_N - 20 ] 
}

*** Total purchases exclude the industries 2, 8, 26, 27, 28.  [_N] refers to total observations.
***  Thus, observation [48 - 46] is industry 2, mining and quarrying(energy)
*** This drops the industries involved in energy production.
*** Mining/Quaryying (energy), Coke/Refined Petroleum, Electricity, Gas, Steam

save master`y', replace

*******************************************************************************
** Use the same methodology to calculate total intermediate imported inputs  **
** Note: Feenstra and Hanson (1999) estimate this, using total inputs times  **
**  (total imports/ shipments + imports - exports)                           **
** With the OECD I-O tables, we have intermediate imported inputs given in   **
** the Input IO table.                                                       **
*******************************************************************************

mkmat i1-i48, matrix(I)
matrix i = I'
svmat i, names(col)
generate total_int_imports =  r1 + r3 + r4 + r5 +r6 +r7 +r9 +r10 +r11 +r12 +r13 +r14 +r15 +r16 +r17 +r18 + r19 +r20 +r21 +r22 +r23 +r24 +r25 +r29+r30+r31+r32+r33+r34+r35+r36+r37+r38+r39+r40+r41+r42+r43+r44+r45+r46+r47+r48

drop r1-r48

generate FH_OSS_`y' = (total_int_imports / total_purchase)

}

log close
exit


