clear
set more off
capture log close
log using "log/FH OSS calculation.log", replace

foreach y of global YEAR {

use data/master`y', clear

************************************************************************
** Generate the matrix FH_IMPINT, which is a N x 1 matrix of          **
** import intensity calculated with final goods.                      **
** Each observation matches up with the corresponding industry weight,**
** which is why the index `j' moves through the appropriate row.      **
************************************************************************

mkmat impint, matrix(FH_impint)
 
matrix FH_OSS = J(48,48,0)

forvalues j = 1(1)48 {
  forvalues i = 1(1)48 {
    matrix FH_OSS[`i',`j'] = w[`i',`j'] * FH_impint[`i',1]
   }
  }

**********************************************************************
** The wide measure of outsourcing looks at all inputs into a given **
** industry.  This is the column sum.                               **
** We follow the same idea as in 'Total_Purchase.Do'                **
** Transpose the matrix OSS, sum across rows                        **
**********************************************************************

matrix FH_OSST = FH_OSS'
svmat FH_OSST, names(col)

egen FH_OSS_`y' = rowtotal(r1-r48)

* Now, need to create a measure of FH that excludes energy inputs from the numerator
* need to replace missing values with zero for summation purposes and sum all industries except energy (isicn = 2,8,26-28)
mvencode r1-r48, mv(0) override
generate FH_OSS_exclenergy_`y'=  r1 + r3 + r4 + r5 +r6 +r7 +r9 +r10 +r11 +r12 +r13 +r14 +r15 +r16 +r17 +r18 + r19 +r20 +r21 +r22 +r23 +r24 +r25 +r29+r30+r31+r32+r33+r34+r35+r36+r37+r38+r39+r40+r41+r42+r43+r44+r45+r46+r47+r48
drop r1-r48


**********************************************************************
** OSS and OSS_Wide now both make up a 48 x 48 square matrix        **
** I use this property to easily make two column vectors            **
** for the variables OSS_wide and OSS_narrow using the vecdiag()    **
** function, which takes the diagonal and makes a column vector.    **
** The column vectors can be more easily worked with in excel or in **
** regressions in Stata.                                            **
**********************************************************************

matrix FH_OSS_narrow = vecdiag(FH_OSS)
matrix FH_OSS_Narrow = FH_OSS_narrow'
svmat FH_OSS_Narrow, name(FH_OSS_Narrow)

rename FH_OSS_Narrow FH_OSS_narrow_`y'

save data/master`y', replace

}

log close
exit
