clear
capture log close
log using "log/OSS calculation.log", replace

set more off

foreach y of global YEAR {

use data/master`y', clear

***************************************************************
** This generates the total non energy inputs by industry i  **
** By creating a matrix, transposing the data and creating   **
** new variables r1 - r48.  Stata operates by rows.  Thus,   **
** Summing up variables r1 thru 48 is now the same operation **
** as summing up the variable t1 (the column of total inputs **
** for ISICN industry 1                                      **
***************************************************************

mkmat t1-t48, matrix(T)

*** Transpose the data

matrix t = T'

*** The command svmatt turns the matrix T into a series of variables, with the columns named r1 thr r48.  
***  Each number corresponds to the industry.  That is, r1 entry 2 is input from industry one into industry two
***  since we transposed the I-O table. 

svmat t, names(col)

*** Total purchases exclude the industries 2, 8, 26, 27, 28 
*** This drops the following industries involved in energy production:
*** Mining/Quaryying (energy), Coke/Refined Petroleum, Electricity, Gas, Steam

* Measure of total non energy purchases, for use in the denominator of OECD FH calculation and weight variable of F&H
generate total_purchase =  r1 + r3 + r4 + r5 +r6 +r7 +r9 +r10 +r11 +r12 +r13 +r14 +r15 +r16 +r17 +r18 + r19 +r20 +r21 +r22 +r23 +r24 +r25 +r29+r30+r31+r32+r33+r34+r35+r36+r37+r38+r39+r40+r41+r42+r43+r44+r45+r46+r47+r48

* Measure of total output, for use in denominator of G&G variable
generate total_output = r49

drop r1-r49

*******************************************************************************
** Use the same methodology to calculate total intermediate imported inputs  **
** Note: Feenstra and Hanson (1999) estimate this, using total inputs times  **
**  (total imports/ shipments + imports - exports)                           **
** With the OECD I-O tables, we have intermediate imported inputs given in   **
** the Input IO table.                                                       **
** We can also use the vecdiag command in the Stata matrix language, and     **
** create a column vector of the intermediate inputs from j to i, where j = i**
**  This is our definition of narrow outsourcing.                            **
*******************************************************************************

mkmat i1-i48, matrix(I)
matrix i = I'
svmat i, names(col)

* generate a measure of total non-energy intermediate imports, for the numerator of the OECD version of FH variable
generate total_nonenergy_int_imports =  r1 + r3 + r4 + r5 +r6 +r7 +r9 +r10 +r11 +r12 +r13 +r14 +r15 +r16 +r17 +r18 + r19 +r20 +r21 +r22 +r23 +r24 +r25 +r29+r30+r31+r32+r33+r34+r35+r36+r37+r38+r39+r40+r41+r42+r43+r44+r45+r46+r47+r48

* generate a measure of total intermediate imports, for use in the numerator of the G&G measure
* Remember that we named the 'total' row isicn 49 from the 'getdata' do file

generate total_int_imports = r49
drop r1-r49

** Now we are done with the column totals saved as isicn 49 **
drop if isicn == 49 

** Generate narrow measure of outsourcing using the vecdiag command.  Note, we need a square matrix, 
** and thus, need to drop isicn == 49.

mkmat i1-i48, matrix(narrow)
matrix narrow = vecdiag(narrow)
matrix narrow = narrow'
svmat narrow, name(narrow)

*******************************************************************************************************************
*** Following OECD STI Working Paper 'The measurement of Globalisation using International Input-Output Tables'  **
*** page page 16, we calculate the outsourcing intensity as the ratio of total imported intermediate inputs to   **
*** total non energy inputs.  They calculate the denominator as imports + domestic.  Note this is what the       **
*** Total IO tab represents.                                                                                     **
*******************************************************************************************************************

generate OSS_`y' = (total_nonenergy_int_imports / total_purchase)

generate OSS_narrow_`y' = (narrow / total_purchase)

save data/master`y', replace

*******************************************************************
**  Generate Geishecker and Gorg (2008) measure of outsourcing   **
**   using total output                                          **
*******************************************************************

generate GG_OSS_`y' = ( total_int_imports / total_output ) 

generate GG_OSS_narrow_`y' = (narrow / total_output )  

save data/master`y', replace

}

log close
exit


