** Analysis.do created by Craig Aubuchon on May 7, 2009
** Merge outsourcing measures for 1995, 2000, 2005
** Plot changes over time, within industries
** Calculate correlation measures between three OSS measures

clear
capture log close
log using log/analysis.log, replace
set more off
cd "D:\work\Subhayu\OECD Data\OSS Measure"
adopath + prog


use data/OSS_results_July09_1995

merge isicn using data/OSS_results_July09_2000 data/OSS_results_July09_2005, sort
assert _merge == 3
drop _merge1 _merge2 _merge

** Group the OSS measures by type (FH < GG < OECD)
aorder
order isicn industry  FH_OSS_1995-OSS_narrow_1995 impint_ratio_check_1995 FH_OSS_2000-OSS_narrow_2000 impint_ratio_check_2000 FH_OSS_2005-OSS_narrow_2005 impint_ratio_check_2005

save data/analysis, replace

** Outsheet the raw OSS measures, by year
outsheet isicn industry FH_OSS_1995 FH_OSS_exclenergy_1995 GG_OSS_1995 OSS_1995 impint_ratio_check_1995 using results/OSS_1995, replace
outsheet isicn industry FH_OSS_2000 FH_OSS_exclenergy_2000 GG_OSS_2000 OSS_2000 impint_ratio_check_2000 using results/OSS_2000, replace
outsheet isicn industry FH_OSS_2005 FH_OSS_exclenergy_2005 GG_OSS_2005 OSS_2005 impint_ratio_check_2005 using results/OSS_2005, replace

outsheet isicn industry FH_OSS_narrow_1995 GG_OSS_narrow_1995 OSS_narrow_1995 using results/OSS_narrow_1995, replace
outsheet isicn industry FH_OSS_narrow_2000 GG_OSS_narrow_2000 OSS_narrow_2000 using results/OSS_narrow_2000, replace
outsheet isicn industry FH_OSS_narrow_2005 GG_OSS_narrow_2005 OSS_narrow_2005 using results/OSS_narrow_2005, replace

** Calculate correlation measures. Compare Narrow measures to Narrow measures; Wide measures to wide measures.
** Two possible ways to think about correlation: between measures for a given year, across all industries
**  or as the correlation between measures for a given industry, across all years

* Wide Measures, across all industries
pwcorr FH_OSS_1995 FH_OSS_exclenergy_1995 GG_OSS_1995 OSS_1995, sig
pwcorr FH_OSS_2000 FH_OSS_exclenergy_2000 GG_OSS_2000 OSS_2000, sig 
pwcorr FH_OSS_2005 FH_OSS_exclenergy_2005 GG_OSS_2005 OSS_2005, sig

* Narrow Measures, across all industries
pwcorr FH_OSS_narrow_1995 GG_OSS_narrow_1995 OSS_narrow_1995, sig
pwcorr FH_OSS_narrow_2000 GG_OSS_narrow_2000 OSS_narrow_2000, sig
pwcorr FH_OSS_narrow_2005 GG_OSS_narrow_2005 OSS_narrow_2005, sig

save data/correlation_wide, replace

** Remove the industry, Coke and Refined Petroleum (isicn == 8) as an outlier
** Only industry with import intensity greater than 1 (under the FH measure)

drop if isicn == 8

* Wide Measures, across all industries
pwcorr FH_OSS_1995 FH_OSS_exclenergy_1995 GG_OSS_1995 OSS_1995, sig
pwcorr FH_OSS_2000 FH_OSS_exclenergy_2000 GG_OSS_2000 OSS_2000, sig 
pwcorr FH_OSS_2005 FH_OSS_exclenergy_2005 GG_OSS_2005 OSS_2005, sig

* Narrow Measures, across all industries
pwcorr FH_OSS_narrow_1995 GG_OSS_narrow_1995 OSS_narrow_1995, sig
pwcorr FH_OSS_narrow_2000 GG_OSS_narrow_2000 OSS_narrow_2000, sig
pwcorr FH_OSS_narrow_2005 GG_OSS_narrow_2005 OSS_narrow_2005, sig

note: Data Set excludes ISICN == 8
save data/correlation_wide_excl8, replace

* Transpose data using the RESHAPE command, to calculate correlation measures within industries across all years

use data/analysis, clear

reshape long  FH_OSS_  FH_OSS_exclenergy_  FH_OSS_narrow_  GG_OSS_ GG_OSS_narrow_  OSS_ OSS_narrow_, i(isicn) j(year)
sort isicn year
pwcorr FH_OSS_ FH_OSS_exclenergy_ GG_OSS_ OSS_, sig 
pwcorr FH_OSS_narrow_ GG_OSS_narrow_ OSS_narrow_, sig 

save data/correlation_long, replace

*** Calculate percentage change between 1995, 2000 and 2005 for each of the three measures
* NOTE: I calculate difference between periods
* An alternative would be to calculate the ln of annualized growth: ln ( x/ x(t-1) ) / period (5 or 10 years) 
 
use data/analysis, clear

local outsourcing "OSS OSS_narrow GG_OSS GG_OSS_narrow FH_OSS FH_OSS_exclenergy FH_OSS_narrow"

foreach x of local outsourcing {

generate `x'_chg_00 = ( ( `x'_2000 / `x'_1995 )^(1/5) - 1 ) 
label var `x'_chg_00 "compound annual growth rate"
generate `x'_chg_05 = ( ( `x'_2005 / `x'_2000 )^(1/5) - 1 ) 
label var `x'_chg_05 "compound annual growth rate"
generate `x'_chg_10 = ( ( `x'_2005 / `x'_1995 )^(1/10) - 1 ) 
label var `x'_chg_10 "compound annual growth rate"

}

keep isicn industry OSS_chg_00- FH_OSS_narrow_chg_10

* Sort descending

gsort -OSS_chg_10
save data/OSS_growth, replace

** A good way to visualize the data is to first consider the fastest growing manufacturing sectors 
** and the fastest growing service sectors
** Need to split the data into two groups, using KEEP command

* Manufacturing Sector: Consider Textiles, Wood Products, Pulp/Paper, Coke/Refined Petroleum, 
* Chemicals, Pharmaceuticals, Rubber/Plastic, Non-metallic Minerals, Iron/Steel, Non-Ferrous Metals, 
* Fabricated Metal Products, Machinery/Equipment

keep if isicn >= 4 & isicn <= 25
list isicn industry OSS_chg_10 in 1/5

outsheet isicn industry OSS_chg_10 using results/manufacturing_growth, replace

save data/manufacturing_growth, replace

* Service Sector
use data/OSS_growth, replace

keep if isicn >= 30 & isicn <= 46
list isicn industry in 1/5

outsheet isicn industry OSS_chg_10 using results/services_growth, replace

save data/service_growth, replace 

