clear
capture log close
log using log/getdata.log, replace
set more off

*** This do file imports the data from the three different sections of the IO table.
***  Please note that the IO excel tables must be formated correctly and saved as *.csv files
***  For this project, the naming convention is such that each column is named t[_n], where
***  't' stands for total, _n stands for the ISICN number.  Similarly, i[_n] is for imports and 
***  d[_n] is for domestic tab.  

foreach y of global YEAR {

********************
** Total IO       **
********************

insheet using data/total`y'.csv, comma names 
rename lessimports imports
generate production =  c1totalintermediate + finalconsumptionexpenditurebyhou + finalconsumptionexpenditurebynon + finalconsumptionexpenditurebygov + grossfixedcapitalformation - changesininventories + valuables - exports + imports
replace isicn = 49 if industry == "r8 Industry Output" 
label define isicn_label 49 "total output" 
label values isicn isicn_label 
keep isicn industry t1-t48 production 
sort isicn 
drop if isicn ==. 
save data/total`y', replace 
clear 

*********************
** Import IO       **
*********************

insheet using data/import`y'.csv, comma names
keep isicn industry i1-i48 imports
replace isicn = 49 if industry == "Total"
label define import_isicn_label 49 "total imported inputs"
label values isicn import_isicn_label

sort isicn
drop if isicn ==.
save data/import`y', replace
clear

*********************
** Domestic IO     **
*********************

insheet using data/domestic`y'.csv, comma names
generate domesticproduction =  total_int + hhfc + npish + ggfc + gfcf
keep isicn industry d1-d48 domesticproduction
compress
sort isicn
drop if isicn ==.
save data/domestic`y', replace
clear
}

log close
exit
